@@ -348,7 +348,6 @@ DECLARE
   change_user ALIAS FOR $2;
   key ALIAS FOR $3;
   value ALIAS FOR $4;
-  tmp_int INT;
 BEGIN
   -- Check that there is either a resource, collection or user at this location.
   IF NOT EXISTS(        SELECT 1 FROM caldav_data WHERE dav_name = path
@@ -358,11 +357,11 @@ BEGIN
                ) THEN
     RETURN FALSE;
   END IF;
-  SELECT changed_by INTO tmp_int FROM property WHERE dav_name = path AND property_name = key;
+  PERFORM true FROM property WHERE dav_name = path AND property_name = key;
   IF FOUND THEN
-    UPDATE property SET changed_by=change_user, changed_on=current_timestamp, property_value=value WHERE dav_name = path AND property_name = key;
+    UPDATE property SET changed_by=change_user::integer, changed_on=current_timestamp, property_value=value WHERE dav_name = path AND property_name = key;
   ELSE
-    INSERT INTO property ( dav_name, changed_by, changed_on, property_name, property_value ) VALUES( path, change_user, current_timestamp, key, value );
+    INSERT INTO property ( dav_name, changed_by, changed_on, property_name, property_value ) VALUES( path, change_user::integer, current_timestamp, key, value );
   END IF;
   RETURN TRUE;
 END;
@@ -929,7 +928,12 @@ BEGIN
       SELECT privileges FROM grants WHERE by_principal=in_grantor AND by_collection IS NULL
                                           AND (to_principal=in_accessor OR to_principal IN (SELECT expand_memberships(in_accessor,in_depth)))
             UNION
-      SELECT 32::BIT(24) AS privileges FROM expand_memberships(in_accessor,in_depth) WHERE expand_memberships = in_grantor
+      SELECT bit_or(sq2.privileges) FROM
+      (
+          SELECT 32::BIT(24) AS privileges FROM expand_memberships(in_accessor,in_depth) WHERE expand_memberships = in_grantor
+      			UNION
+          SELECT default_privileges AS privileges FROM principal WHERE principal_id = in_grantor
+      ) AS sq2
     ) AS subquery ;
 
   IF out_conferred IS NULL THEN
@@ -1013,7 +1017,7 @@ BEGIN
     RETURN ~ out_conferred;
   END IF;
 
-  SELECT privileges INTO out_conferred FROM grants
+  SELECT bit_or(privileges) INTO out_conferred FROM grants
                    WHERE by_collection = grantor_collection
                      AND (to_principal=in_accessor OR to_principal IN (SELECT expand_memberships(in_accessor,in_depth)));
 
@@ -1206,25 +1210,42 @@ DECLARE
   in_old_sync_token ALIAS FOR $1;
   in_collection_id ALIAS FOR $2;
   tmp_int INT8;
+  new_token sync_tokens.sync_token%TYPE;
   old_modification_time sync_tokens.modification_time%TYPE;
 BEGIN
   IF in_old_sync_token > 0 THEN
-    SELECT modification_time INTO old_modification_time FROM sync_tokens WHERE sync_token = in_old_sync_token;
+    SELECT modification_time INTO old_modification_time FROM sync_tokens
+           WHERE sync_token = in_old_sync_token AND collection_id = in_collection_id;
     IF NOT FOUND THEN
       -- They are in an inconsistent state: we return NULL so they can re-start the process
       RETURN NULL;
     END IF;
+  END IF;
+  
+  -- Find the most recent sync_token
+  SELECT sync_token, modification_time INTO new_token, old_modification_time FROM sync_tokens
+         WHERE collection_id = in_collection_id ORDER BY modification_time DESC LIMIT 1;
+  IF FOUND THEN
     SELECT 1 INTO tmp_int FROM sync_changes WHERE collection_id = in_collection_id AND sync_time > old_modification_time LIMIT 1;
     IF NOT FOUND THEN
-      -- Ensure we return the latest sync_token we have for this collection, since there are
-      -- no changes.
-	  SELECT sync_token INTO tmp_int FROM sync_tokens WHERE collection_id = in_collection_id ORDER BY modification_time DESC LIMIT 1;
-      RETURN tmp_int;
+      -- Return the latest sync_token we have for this collection, since there are no changes.
+      RETURN new_token;
     END IF;
   END IF;
-  SELECT nextval('sync_tokens_sync_token_seq') INTO tmp_int;
-  INSERT INTO sync_tokens(collection_id, sync_token) VALUES( in_collection_id, tmp_int );
-  RETURN tmp_int;
+  
+  -- Looks like we need a new sync_token for this collection...
+  SELECT nextval('sync_tokens_sync_token_seq') INTO new_token;
+  INSERT INTO sync_tokens(collection_id, sync_token) VALUES( in_collection_id, new_token );
+  
+  -- Having created our new token we do some clean-up of old tokens
+  SELECT modification_time, sync_token INTO old_modification_time, tmp_int FROM sync_tokens
+  		WHERE collection_id = in_collection_id AND modification_time < (current_timestamp - '7 days'::interval)
+  		ORDER BY collection_id, modification_time DESC;
+  DELETE FROM sync_changes WHERE collection_id = in_collection_id AND sync_time < old_modification_time;
+  DELETE FROM sync_tokens WHERE collection_id = in_collection_id AND sync_token < tmp_int;
+  
+  -- Returning the new token
+  RETURN new_token;
 END
 $$ LANGUAGE 'PlPgSQL' STRICT;
 
@@ -1249,3 +1270,80 @@ END;
 $$ LANGUAGE plpgsql;
 CREATE TRIGGER alarm_changed AFTER UPDATE ON calendar_alarm
     FOR EACH ROW EXECUTE PROCEDURE alarm_changed();
+
+CREATE or REPLACE FUNCTION real_path_exists( TEXT ) RETURNS BOOLEAN AS $$
+DECLARE
+  in_path ALIAS FOR $1;
+  tmp BOOLEAN;
+BEGIN
+  IF in_path = '/' THEN
+    RETURN TRUE;
+  END IF;
+  IF in_path ~ '^/[^/]+/$' THEN
+    SELECT TRUE INTO tmp FROM usr WHERE username = substring( in_path from 2 for length(in_path) - 2);
+    IF FOUND THEN
+      RETURN TRUE;
+    END IF;
+  ELSE
+    IF in_path ~ '^/.*/$' THEN
+      SELECT TRUE INTO tmp FROM collection WHERE dav_name = in_path;
+      IF FOUND THEN
+        RETURN TRUE;
+      END IF;
+    END IF;
+  END IF;
+  RETURN FALSE;
+END;
+$$ LANGUAGE plpgsql ;
+
+
+
+CREATE or REPLACE FUNCTION collections_within( INT, INT ) RETURNS SETOF INT AS $$
+DECLARE
+    in_collection_id ALIAS FOR $1;
+    in_depth ALIAS FOR $2;
+    resource_id INT;
+    found_some BOOLEAN;
+BEGIN
+    in_depth := in_depth - 1;
+    found_some = FALSE;
+	FOR resource_id IN SELECT b.bound_source_id FROM dav_binding b
+                        JOIN collection pc ON (b.parent_container = pc.dav_name)
+                        WHERE pc.collection_id = in_collection_id
+    LOOP
+        found_some = TRUE;
+        RETURN NEXT resource_id;
+        IF in_depth > 0 THEN
+            FOR resource_id IN SELECT * FROM collections_within( resource_id, in_depth ) LOOP
+                RETURN NEXT resource_id;
+            END LOOP;
+        END IF;
+    END LOOP;
+    FOR resource_id IN SELECT c.collection_id FROM collection c
+                        JOIN collection pc ON (c.parent_container = pc.dav_name)
+                        WHERE pc.collection_id = in_collection_id
+    LOOP
+        found_some = TRUE;
+        RETURN NEXT resource_id;
+        IF in_depth > 0 THEN
+            FOR resource_id IN SELECT * FROM collections_within( resource_id, in_depth ) LOOP
+                RETURN NEXT resource_id;
+            END LOOP;
+        END IF;
+    END LOOP;
+    IF found_some THEN
+        RETURN;
+    END IF;
+    FOR resource_id IN SELECT c.collection_id FROM collection c
+                        JOIN dav_principal pc ON (c.parent_container = pc.dav_name)
+                        WHERE pc.principal_id = in_collection_id
+    LOOP
+        RETURN NEXT resource_id;
+        IF in_depth > 0 THEN
+            FOR resource_id IN SELECT * FROM collections_within( resource_id, in_depth ) LOOP
+                RETURN NEXT resource_id;
+            END LOOP;
+        END IF;
+    END LOOP;
+END;
+$$ LANGUAGE plpgsql ;
