@@ -18,6 +18,18 @@ unset($session); unset($request); unset($dbconn); unset($_awl_dbconn); unset($in
 // An ultra-simple exception handler to catch errors that occur
 // before we get a more functional exception handler in place...
 function early_exception_handler($e) {
+  if ( !headers_sent() ) {
+    header("Content-type: text/plain");
+    header( sprintf("HTTP/1.1 %d %s", 500, getStatusMessage(500)) );
+  }
+  else {
+    echo "<pre>\n";
+    // Too late to set resultcode :-(
+  }
+  try {
+    @ob_flush(); // Seems like it should be better to do the following but is problematic on PHP5.3 at least: while ( ob_get_level() > 0 ) ob_end_flush();
+  }
+  catch( Exception $ignored ) {}
   echo "Exception [".$e->getCode()."] ".$e->getmessage()."\n";
   echo "At line ", $e->getLine(), " of ", $e->getFile(), "\n";
   echo "================= Stack Trace ===================\n";
@@ -26,10 +38,16 @@ function early_exception_handler($e) {
   foreach( $trace AS $k => $v ) {
     printf( "%s[%d] %s%s%s()\n", $v['file'], $v['line'], (isset($v['class'])?$v['class']:''), (isset($v['type'])?$v['type']:''), (isset($v['function'])?$v['function']:'') );
   }
-  @ob_flush();
+  
 }
 set_exception_handler('early_exception_handler');
 
+$c->default_timezone = ini_get('date.timezone');
+if ( empty($c->default_timezone) ) {
+  $c->default_timezone = 'UTC';
+  date_default_timezone_set('UTC');
+}
+
 // Default some of the configurable values
 $c->sysabbr     = 'davical';
 $c->admin_email = 'admin@davical.example.com';
@@ -55,6 +73,8 @@ $c->default_privileges = array('read-free-busy', 'schedule-deliver');
 
 $c->enable_auto_schedule = true;
 
+$c->schema_major = $c->schema_minor = $c->schema_patch = 0;
+
 $c->stylesheets = array( $c->base_url.'/davical.css' );
 $c->images      = $c->base_url . '/images';
 
@@ -75,7 +95,9 @@ $c->dbg = array();
 
 
 // Utilities
+if ( isset($skip_errors) ) $skip_errors = true;
 if ( ! @include_once('AWLUtilities.php') ) {
+  if ( isset($skip_errors) ) $skip_errors = false;
   $try_paths = array(
         '../../awl/inc'
       , '/usr/share/awl/inc'        // Where it ends up on Debian
@@ -93,6 +115,7 @@ if ( ! @include_once('AWLUtilities.php') ) {
     @ob_flush(); exit(0);
   }
 }
+if ( isset($skip_errors) ) $skip_errors = false;
 
 // Ensure that ../inc is in our included paths as early as possible
 set_include_path( '../inc'. PATH_SEPARATOR. get_include_path());
@@ -159,7 +182,7 @@ if ( isset($_SERVER['HTTP_X_DAVICAL_TESTCASE']) ) {
 else if ( isset($c->dbg['script_start']) && $c->dbg['script_start'] ) {
   // Only log this if more than a little debugging of some sort is turned on, somewhere
   @dbg_error_log( 'LOG', '==========> method =%s= =%s= =%s= =%s= =%s=',
-         $_SERVER['REQUEST_METHOD'], $c->protocol_server_port_script, $_SERVER['PATH_INFO'], $c->base_url, $c->base_directory );
+         $_SERVER['REQUEST_METHOD'], $c->protocol_server_port_script, (isset($_SERVER['PATH_INFO']) ? $_SERVER['PATH_INFO'] : '$_SERVER[PATH_INFO] undefined'), $c->base_url, $c->base_directory );
 }
 
 /**
@@ -167,23 +190,25 @@ else if ( isset($c->dbg['script_start']) && $c->dbg['script_start'] ) {
 * default site locale.  This may be overridden by each user.
 */
 putenv("LANG=". $c->default_locale);
-awl_set_locale($c->default_locale);
-init_gettext( 'davical', $c->locale_path );
+if ( function_exists('awl_set_locale') ) {
+  awl_set_locale($c->default_locale);
+  init_gettext( 'davical', $c->locale_path );
+}
 
 /**
 * Work out our version
 *
 */
 $c->code_version = 0;
-$c->want_awl_version = '0.51';
-$c->version_string = '1.0.2'; // The actual version # is replaced into that during the build /release process
+$c->want_awl_version = '0.53';
+$c->version_string = '1.1.1'; // The actual version # is replaced into that during the build /release process
 if ( isset($c->version_string) && preg_match( '/(\d+)\.(\d+)\.(\d+)(.*)/', $c->version_string, $matches) ) {
   $c->code_major = $matches[1];
   $c->code_minor = $matches[2];
   $c->code_patch = $matches[3];
   $c->code_version = (($c->code_major * 1000) + $c->code_minor).'.'.$c->code_patch;
   dbg_error_log('caldav', 'Version (%d.%d.%d) == %s', $c->code_major, $c->code_minor, $c->code_patch, $c->code_version);
-  header( sprintf('Server: %d.%d', $c->code_major, $c->code_minor) );
+  @header( sprintf('Server: %d.%d', $c->code_major, $c->code_minor) );
 }
 
 /**
@@ -276,9 +301,6 @@ function getStatusMessage($status) {
 function ConstructURL( $partial_path, $force_script = false ) {
   global $c;
 
-  $partial_path = rawurlencode($partial_path);
-  $partial_path = str_replace( '%2F', '/', $partial_path);
-
   if ( ! isset($c->_url_script_path) ) {
     $c->protocol_server_port_script = str_replace( 'index.php', 'caldav.php', $c->protocol_server_port_script);
     $c->_url_script_path = (preg_match('#/$#', $c->protocol_server_port_script) ? 'caldav.php' : '');
@@ -289,10 +311,15 @@ function ConstructURL( $partial_path, $force_script = false ) {
   if ( $force_script ) {
     if ( ! preg_match( '#/caldav\.php$#', $url ) ) $url .= '/caldav.php';
   }
-  $url .= $partial_path;
+  $url .= str_replace( '%2F', '/', rawurlencode($partial_path));
   $url = preg_replace( '#^(https?://.+)//#', '$1/', $url );  // Ensure we don't double any '/'
   $url = preg_replace('#^https?://[^/]+#', '', $url );       // Remove any protocol + hostname portion
 
+  if ( strstr($url, 'caldav.php/caldav.php') !== false ) {
+//    trace_bug('Duplicated caldav.php/ in URL "%s" from partial_path=%s, force_script=%s', $url, $partial_path, ($force_script?'true':'false'));
+    $url = str_replace( 'caldav.php/caldav.php', 'caldav.php', $url );  // Ensure we don't double any 'caldav.php/'
+  }
+
   return $url;
 }
 
@@ -334,8 +361,26 @@ function DeconstructURL( $url, $force_script = false ) {
 * @param string $isodate The date to convert
 */
 function ISODateToHTTPDate( $isodate ) {
+  // It is necessary to use English for this, explicitly.  See Debian BTS Bug#661985 for more info.
+  $month = gmstrftime('%m', strtotime($isodate));
+  switch( intval($month) ) {
+  	case 1: $month = 'Jan'; break;
+  	case 2: $month = 'Feb'; break;
+  	case 3: $month = 'Mar'; break;
+  	case 4: $month = 'Apr'; break;
+  	case 5: $month = 'May'; break;
+  	case 6: $month = 'Jun'; break;
+  	case 7: $month = 'Jul'; break;
+  	case 8: $month = 'Aug'; break;
+  	case 9: $month = 'Sep'; break;
+  	case 10: $month = 'Oct'; break;
+  	case 11: $month = 'Nov'; break;
+  	case 12: $month = 'Dec'; break;
+  	default:
+  		throw new Exception('Invalid month '.$month);
+  }
   // Use strtotime since strptime is not available on Windows platform.
-  return( gmstrftime('%a, %d %b %Y %H:%M:%S GMT', strtotime($isodate)) );
+  return( gmstrftime('%a, %d '.$month.' %Y %H:%M:%S GMT', strtotime($isodate)) );
 }
 
 /**
