@@ -1,10 +1,52 @@
 <?php
 /** todo work out something more than true/false returns for dependency checks */
 
+
 function i18n($value) {
   return $value;  /* Just pass the value through */
 }
 
+$skip_errors = false; // We need to hide a couple of unsightly errors even here...
+function log_setup_error($errno , $errstr , $errfile , $errline) {
+  global $skip_errors;
+  if ( $skip_errors ) return; 
+  error_log('DAViCal setup.php: Informational: '.$errfile.'('.$errline.'): ['.$errno.'] '.$errstr);
+}
+
+function catch_setup_errors($errno , $errstr , $errfile , $errline , $errcontext ) {
+  if ( $errno == 2 ) {
+    // A working installation will regularly fail to include_once() for several files as it searches for the location
+    log_setup_error($errno , $errstr , $errfile , $errline);
+    return true;
+  }
+  if ( $errno == 8 ) {
+    // Yeah, OK, so we redundantly call ob_flash() without needing to...
+    log_setup_error($errno , $errstr , $errfile , $errline);
+    return true;
+  }
+  else if ( $errno == 256 ) {
+    // This will (probably) be a database connection error, which will throw an exception if we return.
+    log_setup_error($errno , $errstr , $errfile , $errline);
+    return true;
+  }
+  if ( !headers_sent() ) header("Content-type: text/plain"); else echo "<pre>\n";
+  try {
+    @ob_flush(); // Seems like it should be better to do the following but is problematic on PHP5.3 at least: while ( ob_get_level() > 0 ) ob_end_flush();
+  }
+  catch( Exception $ignored ) {}
+  echo "Error [".$errno."] ".$errstr."\n";
+  echo "At line ", $errline, " of ", $errfile, "\n";
+
+  $e = new Exception();
+  $trace = array_reverse($e->getTrace());
+  echo "================= Stack Trace ===================\n";
+  foreach( $trace AS $k => $v ) {
+    printf( "%s[%d] %s%s%s()\n", $v['file'], $v['line'], (isset($v['class'])?$v['class']:''), (isset($v['type'])?$v['type']:''), (isset($v['function'])?$v['function']:'') );
+  }
+}
+
+set_error_handler('catch_setup_errors', E_ALL);
+
 class CheckResult {
   private $ok;
   private $use_class;
@@ -57,6 +99,13 @@ function check_pdo_pgsql() {
   return new CheckResult(isset($loaded_extensions['pdo_pgsql']));
 }
 
+function check_database_connection() {
+  global $c;
+
+  if ( !check_pdo_pgsql() ) return new CheckResult(false);
+  return new CheckResult( !( empty($c->schema_major) || $c->schema_major == 0 || empty($c->schema_minor) || $c->schema_minor == 0) );
+}
+
 function check_gettext() {
   global $phpinfo, $loaded_extensions;
 
@@ -96,7 +145,9 @@ function check_suhosin_server_strip() {
   global $loaded_extensions;
 
   if ( !isset($loaded_extensions['suhosin']) ) return new CheckResult(true);
-  return new CheckResult( ini_get('suhosin.server.strip') == "0" || strtolower(ini_get('suhosin.server.strip')) == "off" );
+  return new CheckResult( ini_get('suhosin.server.strip') == "0"
+       || strtolower(ini_get('suhosin.server.strip')) == "off"
+       || ini_get('suhosin.server.strip') == "" );
 }
 
 function check_magic_quotes_gpc() {
@@ -127,6 +178,7 @@ if ( !check_gettext()->getOK() )   do_error("The GNU 'gettext' extension for PHP
 if ( !check_pgsql()->getOK() )     do_error("PHP 'pgsql' functions are not available");
 if ( !check_pdo()->getOK() )       do_error("PHP 'PDO' module is not available");
 if ( !check_pdo_pgsql()->getOK() ) do_error("The PDO drivers for PostgreSQL are not available");
+if ( !check_database_connection()->getOK() ) do_error("Unable to connect to database");
 if ( !check_iconv()->getOK() )     do_error("The 'iconv' extension for PHP is not available");
 
 function get_phpinfo() {
@@ -141,12 +193,21 @@ function get_phpinfo() {
 }
 $phpinfo = get_phpinfo();
 
-include("./always.php");
-include("DAViCalSession.php");
-
-
-if ( check_pgsql()->GetOK() ) {
-  $session->LoginRequired( (isset($c->restrict_setup_to_admin) && $c->restrict_setup_to_admin ? 'Admin' : null ) );
+try {
+  include("./always.php");
+  set_error_handler('log_setup_error', E_ALL);
+  include("DAViCalSession.php");
+  if ( check_pgsql()->GetOK() ) {
+    $session->LoginRequired( (isset($c->restrict_setup_to_admin) && $c->restrict_setup_to_admin ? 'Admin' : null ) );
+  }
+}
+catch( Exception $e ) {
+  class FakeSession {
+    function AllowedTo() {
+      return true;
+    }
+  }
+  $session = new FakeSession(1);
 }
 
 
@@ -195,8 +256,13 @@ function check_davical_version() {
   fclose($version_file);
   $result = new CheckResult($c->version_string == $current_version);
   if ( ! $result->getOK() ) {
-    $result->setDescription( sprintf(i18n('Want: %s, Currently: %s'), $current_version, $c->version_string) );
-    if ( $c->version_string > $current_version ) $result->setClass('dep_warning');
+    if ( $c->version_string > $current_version ) {
+      $result->setClass('dep_ok');
+      $result->setDescription( sprintf(i18n('Stable: %s, We have: %s !'), $current_version, $c->version_string) );
+    }
+    else {
+      $result->setDescription( sprintf(i18n('Want: %s, Currently: %s'), $current_version, $c->version_string) );
+    }
   }
   return $result;
 }
@@ -228,7 +294,7 @@ function build_site_statistics() {
 </table>
 EOTABLE;
 
-  if ( !check_pdo_pgsql() ) {
+  if ( !check_database_connection() ) {
     return sprintf( $table, '<td colspan="3">'.translate('Site Statistics require the database to be available!').'</td>');
   }
   $sql = 'SELECT
@@ -250,12 +316,12 @@ function build_dependencies_table( ) {
   
   $dependencies = array(
     translate('Current DAViCal version ')         => 'check_davical_version',
-    translate('DAViCal DB Schema version ')       => 'check_schema_version',
     translate('AWL Library version ')             => 'check_awl_version',
     translate('PHP not using Apache Filter mode') => 'check_real_php',
     translate('PHP PDO module available')         => 'check_pdo',
     translate('PDO PostgreSQL drivers')           => 'check_pdo_pgsql',
-//    translate('PHP PostgreSQL available')         => 'check_pgsql',
+    translate('Database is Connected')            => 'check_database_connection',
+    translate('DAViCal DB Schema version ')       => 'check_schema_version',
     translate('GNU gettext support')              => 'check_gettext',
     translate('PHP iconv support')                => 'check_iconv',
     translate('PHP DateTime class')               => 'check_datetime',
@@ -312,7 +378,17 @@ $th_status     = translate('Status');
 $dependencies_table = build_dependencies_table();
 
 $heading_site_statistics = translate('Site Statistics');
-$site_statistics_table = build_site_statistics();
+if ( check_database_connection()->GetOK() ) {
+  try {
+    $site_statistics_table = build_site_statistics();
+  }
+  catch( Exception $e ) {
+    $site_statistics_table = "Statistics unavailable";
+  }
+}
+else {
+  $site_statistics_table = "Statistics unavailable";
+}
 
 $heading_config_clients = translate('Configuring Calendar Clients for DAViCal');
 $heading_config_davical = translate('Configuring DAViCal');
