@@ -271,7 +271,7 @@ class DAVResource
     else {
       $this->resourcetypes = '';
       if ( isset($this->resource->caldav_data) ) {
-        $this->resource->displayname = $this->resource->summary;
+        if ( isset($this->resource->summary) )$this->resource->displayname = $this->resource->summary;
         if ( strtoupper(substr($this->resource->caldav_data,0,15)) == 'BEGIN:VCALENDAR' ) {
           $this->contenttype = 'text/calendar';
           if ( !$this->HavePrivilegeTo('read') && $this->HavePrivilegeTo('read-free-busy') ) {
@@ -292,6 +292,7 @@ class DAVResource
               $comp->ClearComponents('VALARM');
               $vcal2->AddComponent($comp);
             }
+            $this->resource->displayname = $this->resource->summary = $vcal2->GetPValue('SUMMARY');
             $this->resource->caldav_data = $vcal2->Render();
           }
         }
@@ -429,7 +430,7 @@ FROM dav_binding
 EOSQL;
       $params = array( ':raw_path' => $this->dav_name, ':session_principal' => $session->principal_id, ':scan_depth' => $c->permission_scan_depth );
       if ( !preg_match( '#/$#', $this->dav_name ) ) {
-        $sql .= ' OR dav_binding.dav_name = :up_to_slash OR collection.dav_name = :plus_slash ';
+        $sql .= ' OR dav_binding.dav_name = :up_to_slash OR collection.dav_name = :plus_slash OR dav_binding.dav_name = :plus_slash ';
         $params[':up_to_slash'] = preg_replace( '#[^/]*$#', '', $this->dav_name);
         $params[':plus_slash']  = $this->dav_name.'/';
       }
@@ -596,8 +597,8 @@ EOSQL;
 
     $sql = <<<EOQRY
 SELECT calendar_item.*, addressbook_resource.*, caldav_data.*
-     FROM caldav_data LEFT JOIN calendar_item USING (collection_id,dav_id)
-                       LEFT JOIN addressbook_resource USING (dav_id)
+     FROM caldav_data LEFT OUTER JOIN calendar_item USING (collection_id,dav_id)
+                       LEFT OUTER JOIN addressbook_resource USING (dav_id)
      WHERE caldav_data.dav_name = :dav_name
 EOQRY;
     $params = array( ':dav_name' => $this->bound_from() );
@@ -626,11 +627,37 @@ EOQRY;
     $qry = new AwlQuery('SELECT property_name, property_value FROM property WHERE dav_name= :dav_name', array(':dav_name' => $this->dav_name) );
     if ( $qry->Exec('DAVResource') ) {
       while ( $property = $qry->Fetch() ) {
-        $this->dead_properties[$property->property_name] = $property->property_value;
+        $this->dead_properties[$property->property_name] = self::BuildDeadPropertyXML($property->property_name,$property->property_value);
       }
     }
   }
 
+  public static function BuildDeadPropertyXML($property_name, $raw_string) {
+    if ( !preg_match('{^\s*<.*>\s*$}s', $raw_string) ) return $raw_string;
+    $xmlns = null;
+    if ( preg_match( '{^(.*):([^:]+)$}', $property_name, $matches) ) {
+      $xmlns = $matches[1];
+      $property_name = $matches[2];
+    }
+    $xml = sprintf('<%s%s>%s</%s>', $property_name, (isset($xmlns)?' xmlns="'.$xmlns.'"':''), $raw_string, $property_name);
+    $xml_parser = xml_parser_create_ns('UTF-8');
+    $xml_tags = array();
+    xml_parser_set_option ( $xml_parser, XML_OPTION_SKIP_WHITE, 1 );
+    xml_parser_set_option ( $xml_parser, XML_OPTION_CASE_FOLDING, 0 );
+    $rc = xml_parse_into_struct( $xml_parser, $xml, $xml_tags );
+    if ( $rc == false ) {
+      dbg_error_log( 'ERROR', 'XML parsing error: %s at line %d, column %d',
+                  xml_error_string(xml_get_error_code($xml_parser)),
+                  xml_get_current_line_number($xml_parser), xml_get_current_column_number($xml_parser) );
+      dbg_error_log( 'ERROR', "Error occurred in:\n%s\n",$xml);
+      return $raw_string;
+    }
+    xml_parser_free($xml_parser);
+    $position = 0;
+    $xmltree = BuildXMLTree( $xml_tags, $position);
+    $content = $xmltree->GetContent();
+    return $content[0];
+  }
 
   /**
   * Build permissions for this URL
@@ -728,7 +755,7 @@ EOQRY;
 
 
   /**
-  * Is the user has the privileges to do what is requested.
+  * Does the user have the privileges to do what is requested.
   * @param $do_what mixed The request privilege name, or array of privilege names, to be checked.
   * @param $any boolean Whether we accept any of the privileges. The default is true, unless the requested privilege is 'all', when it is false.
   * @return boolean Whether they do have one of those privileges against this resource.
@@ -1259,6 +1286,25 @@ EOQRY;
   }
 
 
+  /**
+   * Returns the current sync_token for this collection, or the containing collection
+   */
+  function sync_token() {
+    if ( $this->IsPrincipal() ) return null;
+    if ( $this->collection_id() == 0 ) return null;
+    if ( !isset($this->sync_token) ) { 
+      $sql = 'SELECT new_sync_token( 0, :collection_id) AS sync_token';
+      $params = array( ':collection_id' => $this->collection_id());
+      $qry = new AwlQuery($sql, $params );
+      if ( !$qry->Exec() || !$row = $qry->Fetch() ) {
+        if ( !$qry->QDo('SELECT new_sync_token( 0, :collection_id) AS sync_token', $params) )  throw new Exception('Problem with database query');
+        $row = $qry->Fetch();
+      }
+      $this->sync_token = 'data:,'.$row->sync_token;
+    }
+    return $this->sync_token;
+  }
+  
   /**
   * Checks whether the target collection is publicly_readable
   */
@@ -1373,7 +1419,7 @@ EOQRY;
 
     switch( $name ) {
       case 'collection_id':
-        return $this->collection->collection_id;
+        return $this->collection_id();
         break;
 
       case 'principal_id':
@@ -1469,7 +1515,7 @@ EOQRY;
     global $c, $session, $request;
 
 //    dbg_error_log( 'DAVResource', 'Processing "%s" on "%s".', $tag, $this->dav_name );
-
+    
     if ( $reply === null ) $reply = $GLOBALS['reply'];
 
     switch( $tag ) {
@@ -1584,14 +1630,18 @@ EOQRY;
       case 'DAV::owner':
         // The principal-URL of the owner
         if ( $this->IsExternal() ){
-          $reply->DAVElement( $prop, 'owner', $reply->href( $this->collection->bound_from ) );
+          $reply->DAVElement( $prop, 'owner', $reply->href( ConstructURL($this->collection->bound_from )) );
         }
         else {
-          if ( !isset($this->principal) ) $this->FetchPrincipal();
-          $reply->DAVElement( $prop, 'owner', $reply->href( $this->principal->url() ) );
+          $reply->DAVElement( $prop, 'owner', $reply->href( ConstructURL(DeconstructURL($this->principal_url())) ) );
         }
         break;
 
+      case 'DAV::add-member':
+        if ( ! $this->_is_collection ) return false;
+        $reply->DAVElement( $prop, 'add-member', $reply->href(ConstructURL(DeconstructURL($this->url())).'?add-member') );
+        break;
+
       // Empty tag responses.
       case 'DAV::group':
       case 'DAV::alternate-URI-set':
@@ -1608,10 +1658,19 @@ EOQRY;
         $reply->NSElement($prop, $tag, $this->unique_tag() );
         break;
 
+      case 'DAV::sync-token':
+        if ( ! $this->_is_collection ) return false;
+        $sync_token = $this->sync_token();
+        if ( empty($sync_token) ) return false;
+        $reply->NSElement($prop, $tag, $sync_token );
+        break;
+
       case 'http://calendarserver.org/ns/:calendar-proxy-read-for':
         $proxy_type = 'read';
       case 'http://calendarserver.org/ns/:calendar-proxy-write-for':
+        if ( isset($c->disable_caldav_proxy) && $c->disable_caldav_proxy ) return false;
         if ( !isset($proxy_type) ) $proxy_type = 'write';
+        // ProxyFor is an already constructed URL
         $reply->CalendarserverElement($prop, 'calendar-proxy-'.$proxy_type.'-for', $reply->href( $this->principal->ProxyFor($proxy_type) ) );
         break;
 
@@ -1636,13 +1695,13 @@ EOQRY;
           if ( isset($this->dead_properties[$tag]) ) {
             $set_of_components = explode('"', $this->dead_properties[$tag]);
             foreach( $set_of_components AS $k => $v ) {
-              if ( !preg_match('{(VEVENT|VTODO|VJOURNAL|VTIMEZONE|VFREEBUSY)}', $v) ) {
+              if ( !preg_match('{(VEVENT|VTODO|VJOURNAL|VTIMEZONE|VFREEBUSY|VPOLL|VAVAILABILITY)}', $v) ) {
                 unset( $set_of_components[$k] );
               }
             }
           }
           else {
-            $set_of_components = array( 'VEVENT', 'VTODO', 'VJOURNAL', 'VTIMEZONE', 'VFREEBUSY' );
+            $set_of_components = array( 'VEVENT', 'VTODO', 'VJOURNAL', 'VTIMEZONE', 'VFREEBUSY', 'VPOLL', 'VAVAILABILITY' );
           }
         }
         else if ( $this->IsSchedulingCollection() )
@@ -1683,7 +1742,7 @@ EOQRY;
         break;
 
       case 'DAV::current-user-principal':
-        $prop->NewElement('current-user-principal', $reply->href( $request->principal->url() ) );
+        $prop->NewElement('current-user-principal', $reply->href( ConstructURL(DeconstructURL($request->principal->url())) ) );
         break;
 
       case 'SOME-DENIED-PROPERTY':  /** indicating the style for future expansion */
@@ -1767,13 +1826,13 @@ EOQRY;
 
     dbg_error_log('DAVResource',':GetPropStat: propstat for href "%s"', $this->dav_name );
 
-    $prop = new XMLElement('prop');
+    $prop = new XMLElement('prop', null, null, 'DAV:');
     $denied = array();
     $not_found = array();
     foreach( $properties AS $k => $tag ) {
       if ( is_object($tag) ) {
         dbg_error_log( 'DAVResource', ':GetPropStat: "$properties" should be an array of text. Assuming this object is an XMLElement!.' );
-        $tag = $tag->GetTag();
+        $tag = $tag->GetNSTag();
       }
       $found = $this->ResourceProperty($tag, $prop, $reply, $denied );
       if ( !$found ) {
@@ -1782,31 +1841,31 @@ EOQRY;
       }
       if ( ! $found ) {
 //        dbg_error_log( 'DAVResource', 'Request for unsupported property "%s" of resource "%s".', $tag, $this->dav_name );
-        $not_found[] = $reply->Tag($tag);
+        $not_found[] = $tag;
       }
     }
     if ( $props_only ) return $prop;
 
-    $status = new XMLElement('status', 'HTTP/1.1 200 OK' );
+    $status = new XMLElement('status', 'HTTP/1.1 200 OK', null, 'DAV:' );
 
-    $elements = array( new XMLElement( 'propstat', array($prop,$status) ) );
+    $elements = array( new XMLElement( 'propstat', array($prop,$status), null, 'DAV:' ) );
 
     if ( count($denied) > 0 ) {
-      $status = new XMLElement('status', 'HTTP/1.1 403 Forbidden' );
-      $noprop = new XMLElement('prop');
+      $status = new XMLElement('status', 'HTTP/1.1 403 Forbidden', null, 'DAV:' );
+      $noprop = new XMLElement('prop', null, null, 'DAV:');
       foreach( $denied AS $k => $v ) {
         $reply->NSElement($noprop, $v);
       }
-      $elements[] = new XMLElement( 'propstat', array( $noprop, $status) );
+      $elements[] = new XMLElement( 'propstat', array( $noprop, $status), null, 'DAV:' );
     }
 
-    if ( count($not_found) > 0 ) {
-      $status = new XMLElement('status', 'HTTP/1.1 404 Not Found' );
-      $noprop = new XMLElement('prop');
+    if ( !$request->PreferMinimal() && count($not_found) > 0 ) {
+      $status = new XMLElement('status', 'HTTP/1.1 404 Not Found', null, 'DAV:' );
+      $noprop = new XMLElement('prop', null, null, 'DAV:');
       foreach( $not_found AS $k => $v ) {
-        $noprop->NewElement($v);
+        $reply->NSElement($noprop,$v);
       }
-      $elements[] = new XMLElement( 'propstat', array( $noprop, $status) );
+      $elements[] = new XMLElement( 'propstat', array( $noprop, $status), null, 'DAV:' );
     }
     return $elements;
   }
@@ -1837,7 +1896,7 @@ EOQRY;
 
     array_unshift( $elements, $reply->href(ConstructURL($dav_name)));
 
-    $response = new XMLElement( 'response', $elements );
+    $response = new XMLElement( 'response', $elements, null, 'DAV:' );
 
     return $response;
   }
