@@ -398,7 +398,7 @@ class Principal {
     $qry = new AwlQuery('SELECT property_name, property_value FROM property WHERE dav_name= :dav_name', array(':dav_name' => $this->dav_name()) );
     if ( $qry->Exec('Principal') ) {
       while ( $property = $qry->Fetch() ) {
-        $this->dead_properties[$property->property_name] = $property->property_value;
+        $this->dead_properties[$property->property_name] = DAVResource::BuildDeadPropertyXML($property->property_name,$property->property_value);
       }
     }
   }
@@ -487,7 +487,7 @@ class Principal {
       default:
         fatal('Unknown internal URL type "'.$type.'"');
     }
-    return $result;
+    return ConstructURL(DeconstructURL($result));
   }
 
   
@@ -532,12 +532,19 @@ class Principal {
     $sql_params = array();
     foreach( self::updateableFields() AS $k ) {
       if ( !isset($field_values->{$k}) && !isset($this->{$k}) ) continue;
+
       $param_name = ':'.$k;
       $sql_params[$param_name] = (isset($field_values->{$k}) ? $field_values->{$k} : $this->{$k});  
-      if ( $k == 'default_privileges' ) {
+      if ( $k  ==  'default_privileges' ) {
         $sql_params[$param_name] = sprintf('%024s',$sql_params[$param_name]);
         $param_name = 'cast('.$param_name.' as text)::BIT(24)';
       }
+      else if ( $k == 'modified'
+               && isset($field_values->{$k})
+               && preg_match('{^([23]\d\d\d[01]\d[0123]\d)T?([012]\d[0-5]\d[0-5]\d)$}', $field_values->{$k}, $matches) ) {
+        $sql_params[$param_name] = $matches[1] . 'T' . $matches[2];
+      }
+
       if ( $inserting ) {
         $param_names[] = $param_name;
         $insert_fields[] = $k;
@@ -553,6 +560,16 @@ class Principal {
           throw new Exception( get_class($this).'::Create: Mandatory field "'.$k.'" is not set.');
         } 
       }
+      if ( isset($this->user_no) ) {
+        $param_names[] = ':user_no';
+        $insert_fields[] = 'user_no'; 
+        $sql_params[':user_no'] = $this->user_no;
+      }
+      if ( isset($this->created) ) {
+        $param_names[] = ':created';
+        $insert_fields[] = 'created';
+        $sql_params[':created'] = $this->created;
+      }
       $sql = 'INSERT INTO '.self::$db_tablename.' ('.implode(',',$insert_fields).') VALUES('.implode(',',$param_names).')';
     }
     else {
