@@ -115,7 +115,7 @@ class Rfc5545Duration {
    */
   function asSeconds() {
     if ( !isset($this->epoch_seconds) ) {
-      if ( preg_match('{^(-?)P(\d+W)|((\d+D)?(T(\d+H)?(\d+M)?(\d+S)?)?)$}i', $subject, $matches) ) {
+      if ( preg_match('{^(-?)P(\d+W)|((\d+D)?(T(\d+H)?(\d+M)?(\d+S)?)?)$}i', $this->as_text, $matches) ) {
         if ( isset($matches[2]) ) $this->days = ($matches[2] * 7);
         else {
           if ( isset($matches[4]) ) $this->days = $matches[4];
@@ -756,6 +756,9 @@ class RepeatRule {
         return array( 'bymonth' => 'limit', 'bymonthday' => 'limit',
                         'byday' => 'limit', 'byhour' => 'limit', 'byminute' => 'limit', 'bysecond' => 'limit' );
     }
+    dbg_error_log('ERROR','Invalid frequency code "%s" - pretending it is "DAILY"', $freq);
+    return array( 'bymonth' => 'limit', 'bymonthday' => 'limit',
+                        'byday' => 'limit', 'byhour' => 'expand', 'byminute' => 'expand', 'bysecond' => 'expand' );
   }
   
   private function GetMoreInstances($return_floating_times=false) {
@@ -1481,6 +1484,11 @@ function getVCalendarRange( $vResource ) {
       foreach ( rdate_expand($dtstart, 'EXDATE', $comp, $range_end) AS $k => $v ) {
         unset($instances[$k]);
       }
+      if ( count($instances) < 1 ) {
+        if ( empty($earliest_start) || $dtstart < $earliest_start ) $earliest_start = $dtstart;
+        $latest_end = null;
+        break;
+      }
       $instances = array_keys($instances);
       asort($instances);
       $first = new RepeatRuleDateTime($instances[0]);
