@@ -17,6 +17,7 @@ $container->NeedPrivilege('DAV::unbind');
 
 $lock_opener = $request->FailIfLocked();
 
+require_once('schedule-functions.php');
 
 function delete_collection( $id ) {
   $params = array( ':collection_id' => $id );
@@ -72,27 +73,35 @@ else {
     $request->DoResponse( 412, translate("Resource has changed on server - not deleted") );
   }
 
-  $params = array( ':dav_id' => $dav_resource->resource_id() );
-
+  // Check to see if we need to do any scheduling transactions for this one.
+  do_scheduling_for_delete($dav_resource);
+  
   // We need to serialise access to this process just for this collection
   $cache = getCacheInstance();
   $myLock = $cache->acquireLock('collection-'.$dav_resource->parent_path());
 
-  if ( $qry->QDo("SELECT write_sync_change(collection_id, 404, caldav_data.dav_name) FROM caldav_data WHERE dav_id = :dav_id", $params )
-    && $qry->QDo("DELETE FROM property WHERE dav_name = (SELECT dav_name FROM caldav_data WHERE dav_id = :dav_id)", $params )
+  $collection_id = $dav_resource->GetProperty('collection_id');
+  $params = array( ':dav_id' => $dav_resource->resource_id() );
+  if ( $qry->QDo("DELETE FROM property WHERE dav_name = (SELECT dav_name FROM caldav_data WHERE dav_id = :dav_id)", $params )
     && $qry->QDo("DELETE FROM locks WHERE dav_name = (SELECT dav_name FROM caldav_data WHERE dav_id = :dav_id)", $params )
-    && $qry->QDo("DELETE FROM caldav_data WHERE dav_id = :dav_id", $params )
-    && $qry->Commit() ) {
-    @dbg_error_log( "DELETE", "DELETE: User: %d, ETag: %s, Path: %s", $session->user_no, $request->etag_if_match, $request->path);
+    && $qry->QDo("SELECT write_sync_change(collection_id, 404, caldav_data.dav_name) FROM caldav_data WHERE dav_id = :dav_id", $params )
+    && $qry->QDo("DELETE FROM caldav_data WHERE dav_id = :dav_id", $params ) ) {
     if ( function_exists('log_caldav_action') ) {
-      log_caldav_action( 'DELETE', $dav_resource->GetProperty('uid'), $dav_resource->GetProperty('user_no'), $dav_resource->GetProperty('collection_id'), $request->path );
+      log_caldav_action( 'DELETE', $dav_resource->GetProperty('uid'), $dav_resource->GetProperty('user_no'), $collection_id, $request->path );
     }
+    
+    $qry->Commit();
+    @dbg_error_log( "DELETE", "DELETE: User: %d, ETag: %s, Path: %s", $session->user_no, $request->etag_if_match, $request->path);
+
+    if ( function_exists('post_commit_action') ) {
+      post_commit_action( 'DELETE', $dav_resource->GetProperty('uid'), $dav_resource->GetProperty('user_no'), $collection_id, $request->path );
+    }
+
     $cache->delete( 'collection-'.$dav_resource->parent_path(), null );
     $cache->releaseLock($myLock);
     $request->DoResponse( 204 );
   }
   $cache->releaseLock($myLock);
-
 }
 
 $request->DoResponse( 500 );
