@@ -13,13 +13,7 @@ dbg_error_log("POST", "method handler");
 require_once("XMLDocument.php");
 include_once('caldav-PUT-functions.php');
 include_once('freebusy-functions.php');
-
-if ( ! $request->AllowedTo("CALDAV:schedule-send-freebusy")
-  && ! $request->AllowedTo("CALDAV:schedule-send-invite")
-  && ! $request->AllowedTo("CALDAV:schedule-send-reply") ) {
-  // $request->DoResponse(403);
-  dbg_error_log( "WARN", ": POST: permissions not yet checked" );
-}
+include_once('iSchedule.php');
 
 if ( ! ini_get('open_basedir') && (isset($c->dbg['ALL']) || isset($c->dbg['post'])) ) {
   $fh = fopen('/tmp/POST.txt','w');
@@ -31,8 +25,9 @@ if ( ! ini_get('open_basedir') && (isset($c->dbg['ALL']) || isset($c->dbg['post'
 
 
 function handle_freebusy_request( $ic ) {
-  global $c, $session, $request;
+  global $c, $session, $request, $ical;
 
+  $request->NeedPrivilege('CALDAV:schedule-send-freebusy');
   $reply = new XMLDocument( array("DAV:" => "", "urn:ietf:params:xml:ns:caldav" => "C" ) );
   $responses = array();
 
@@ -77,9 +72,31 @@ function handle_freebusy_request( $ic ) {
     $reply->CalDAVElement($response, "recipient", $reply->href($attendee->Value()) );
 
     if ( $qry->rows() == 0 ) {
-      $reply->CalDAVElement($response, "request-status", "3.7;Invalid Calendar User" );
-      $reply->CalDAVElement($response, "calendar-data" );
-      $responses[] = $response;
+      $remote = new iSchedule ();
+      $answer = $remote->sendRequest ( $attendee->Value(), 'VFREEBUSY/REQUEST', $ical->Render() );
+      if ( $answer === false ) {
+        $reply->CalDAVElement($response, "request-status", "3.7;Invalid Calendar User" );
+        $reply->CalDAVElement($response, "calendar-data" );
+        $responses[] = $response;
+        continue;
+      }
+      
+      foreach ( $answer as $a )
+      {
+        if ( $a === false ) {
+          $reply->CalDAVElement($response, "request-status", "3.7;Invalid Calendar User" );
+          $reply->CalDAVElement($response, "calendar-data" );
+        }
+        elseif ( substr( $a, 0, 1 ) >= 1 ) {
+          $reply->CalDAVElement($response, "request-status", $a );
+          $reply->CalDAVElement($response, "calendar-data" );
+        }
+        else {
+          $reply->CalDAVElement($response, "request-status", "2.0;Success" );
+          $reply->CalDAVElement($response, "calendar-data", $a );
+        }
+        $responses[] = $response;
+      }
       continue;
     }
     if ( ! $attendee_usr = $qry->Fetch() ) $request->DoResponse( 501, 'Database error');
@@ -114,6 +131,8 @@ function handle_freebusy_request( $ic ) {
 function handle_cancel_request( $ic ) {
   global $c, $session, $request;
 
+  $request->NeedPrivilege('CALDAV:schedule-send-reply');
+  
   $reply = new XMLDocument( array("DAV:" => "", "urn:ietf:params:xml:ns:caldav" => "C" ) );
 
   $response = $reply->NewXMLElement( "response", false, false, 'urn:ietf:params:xml:ns:caldav' );
@@ -122,6 +141,7 @@ function handle_cancel_request( $ic ) {
   $request->XMLResponse( 200, $response );
 }
 
+
 $ical = new vCalendar( $request->raw_post );
 $method =  $ical->GetPValue('METHOD');
 
@@ -133,6 +153,7 @@ switch ( $method ) {
     if ( $first->GetType() == 'VFREEBUSY' )
       handle_freebusy_request( $first );
     elseif ( $first->GetType() == 'VEVENT' ) {
+      $request->NeedPrivilege('CALDAV:schedule-send-invite');
       handle_schedule_request( $ical );
     }
     else {
@@ -141,6 +162,7 @@ switch ( $method ) {
     break;
   case 'REPLY':
     dbg_error_log('POST', 'Handling iTIP "REPLY" with "%s" component.', $first->GetType() );
+    $request->NeedPrivilege('CALDAV:schedule-send-reply');
     handle_schedule_reply ( $ical );
     break;
 
