@@ -31,7 +31,7 @@ else {
   $allprop    = $xmltree->GetPath('/DAV::propfind/*');
   $property_list = array();
   foreach( $allprop AS $k1 => $propwrap ) {
-    switch ( $propwrap->GetTag() ) {
+    switch ( $propwrap->GetNSTag() ) {
       case 'DAV::allprop':
         $property_list[] = 'DAV::allprop';
         break;
@@ -41,7 +41,7 @@ else {
       default:  // prop, include
         $subprop = $propwrap->GetElements();
         foreach( $subprop AS $k => $v ) {
-          if ( is_object($v) && method_exists($v,'GetTag') ) $property_list[] = $v->GetTag();
+          if ( is_object($v) && method_exists($v,'GetTag') ) $property_list[] = $v->GetNSTag();
         }
     }
   }
@@ -169,7 +169,7 @@ function get_collection_contents( $depth, $collection, $parent_path = null ) {
       }
     }
 
-    if ( $collection->IsPrincipal() ) {
+    if ( (!isset($c->disable_caldav_proxy) || $c->disable_caldav_proxy == false) && $collection->IsPrincipal() ) {
       // Caldav Proxy: 5.1 par. 2: Add child resources calendar-proxy-(read|write)
       dbg_error_log('PROPFIND','Adding calendar-proxy-read and write. Path: %s', $bound_from );
       $response = add_proxy_response('read', $bound_from );
@@ -198,7 +198,7 @@ function get_collection_contents( $depth, $collection, $parent_path = null ) {
 
     $sql = 'SELECT collection.*, principal.*, calendar_item.*, caldav_data.*, ';
     $sql .= "to_char(coalesce(calendar_item.created, caldav_data.created) at time zone 'GMT',$date_format) AS created, ";
-    $sql .= "to_char(last_modified at time zone 'GMT',$date_format) AS modified, ";
+    $sql .= "to_char(coalesce(calendar_item.last_modified, caldav_data.modified) at time zone 'GMT',$date_format) AS modified, ";
     $sql .= 'summary AS dav_displayname ';
     $sql .= 'FROM caldav_data LEFT JOIN calendar_item USING( dav_id, user_no, dav_name, collection_id) ';
     $sql .= 'LEFT JOIN collection USING(collection_id,user_no) LEFT JOIN principal USING(user_no) ';
