@@ -19,6 +19,8 @@ require_once('AwlCache.php');
 require_once('vComponent.php');
 require_once('vCalendar.php');
 require_once('WritableCollection.php');
+include_once('iSchedule.php');
+include_once('RRule-v2.php');
 
 $bad_events = null;
 
@@ -122,12 +124,15 @@ VALUES( :user_no, :parent_container, :dav_name, :dav_etag, :dav_displayname, TRU
       );
       $qry->QDo( $sql, $params );
     }
-    else if ( isset($public) && $collection->is_public == ($public?'t':'f') ) {
+    else if ( isset($public) ) {
       $collection = $qry->Fetch();
-      $sql = 'UPDATE collection SET publicly_readable = :is_public::boolean WHERE collection_id = :collection_id';
-      $params = array( ':is_public' => ($public?'t':'f'), ':collection_id' => $collection->collection_id );
-      if ( ! $qry->QDo($sql,$params) ) {
-        rollback_on_error( $caldav_context, $user_no, $path );
+      if ( empty($collection->is_public) ) $collection->is_public = 'f'; 
+      if ( $collection->is_public == ($public?'t':'f')  ) {
+        $sql = 'UPDATE collection SET publicly_readable = :is_public::boolean WHERE collection_id = :collection_id';
+        $params = array( ':is_public' => ($public?'t':'f'), ':collection_id' => $collection->collection_id );
+        if ( ! $qry->QDo($sql,$params) ) {
+          rollback_on_error( $caldav_context, $user_no, $path );
+        }
       }
     }
 
@@ -391,6 +396,7 @@ function do_scheduling_reply( vCalendar $resource, vProperty $organizer ) {
   $resource->UpdateOrganizerStatus($organizer);
   $scheduling_actions = true;
   
+  $calling_attendee = clone($attendee);
   $attendees = $schedule_original->GetAttendees();
   foreach( $attendees AS $attendee ) {
     $email = preg_replace( '/^mailto:/i', '', $attendee->Value() );
@@ -401,10 +407,42 @@ function do_scheduling_reply( vCalendar $resource, vProperty $organizer ) {
       dbg_error_log( "PUT", "not delivering to %s, schedule agent set to value other than server", $email );
       continue;
     }
+
+    // an attendee's reply should modify only the PARTSTAT on other attendees' objects
+    // other properties (that might have been adjusted individually by those other
+    // attendees) should remain unmodified. Therefore, we have to make $schedule_original
+    // and $schedule_request be initialized by each attendee's object here.
+    $attendee_principal = new DAVPrincipal ( array ('email'=>$email, 'options'=> array ( 'allow_by_email' => true ) ) );
+    if ( $attendee_principal == false ){
+      dbg_error_log( 'PUT', 'Could not find attendee %s', $email);
+      continue;
+    }
+    $sql = 'SELECT caldav_data.dav_name, caldav_data.caldav_data, caldav_data.collection_id FROM caldav_data JOIN calendar_item USING(dav_id) ';
+    $sql .= 'WHERE caldav_data.collection_id IN (SELECT collection_id FROM collection WHERE is_calendar AND user_no =?) ';
+    $sql .= 'AND uid=? LIMIT 1';
+    $qry = new AwlQuery($sql,$attendee_principal->user_no(), $uid);
+    if ( !$qry->Exec('PUT',__LINE__,__FILE__) || $qry->rows() < 1 ) {
+      dbg_error_log( 'PUT', "Could not find attendee's event %s", $uid );
+    }
+    $row = $qry->Fetch();
+    $schedule_original = new vCalendar($row->caldav_data);
+    $schedule_original->UpdateAttendeeStatus($request->principal->email(), clone($calling_attendee) );
+    $schedule_request = clone($schedule_original);
+    $schedule_request->AddProperty('METHOD', 'REQUEST');
+
     $schedule_target = new Principal('email',$email);
     $response = '3.7'; // Attendee was not found on server.
     if ( $schedule_target->Exists() ) {
-      $attendee_calendar = new WritableCollection(array('path' => $schedule_target->internal_url('schedule-default-calendar')));
+      // Instead of always writing to schedule-default-calendar, we first try to
+      // find a calendar with an existing instance of the event in any calendar of this attendee.
+      $r = new DAVResource($row);
+      $attendee_calendar = new WritableCollection(array('path' => $r->parent_path()));
+      if ($attendee_calendar->IsCalendar()) {
+        dbg_error_log( 'XXX', "found the event in attendee's calendar %s", $attendee_calendar->dav_name() );
+      } else {
+        dbg_error_log( 'XXX', 'could not find the event in any calendar, using schedule-default-calendar');
+        $attendee_calendar = new WritableCollection(array('path' => $schedule_target->internal_url('schedule-default-calendar')));
+      }
       if ( !$attendee_calendar->Exists() ) {
         dbg_error_log('ERROR','Default calendar at "%s" does not exist for user "%s"',
         $attendee_calendar->dav_name(), $schedule_target->username());
@@ -484,6 +522,13 @@ function do_scheduling_requests( vCalendar $resource, $create, $old_data = null
     $removed_attendees[$email] = $attendee;
   }
 
+  $uids = $resource->GetPropertiesByPath('/VCALENDAR/*/UID');
+  if ( count($uids) == 0 ) {
+    dbg_error_log( 'PUT', 'No UID in VCALENDAR - giving up on REPLY.' );
+    return false;
+  }
+  $uid = $uids[0]->Value();
+
   dbg_error_log( 'PUT', 'Writing scheduling resources for %d attendees', count($attendees) );
   $scheduling_actions = false;
   foreach( $attendees AS $attendee ) {
@@ -511,7 +556,26 @@ function do_scheduling_requests( vCalendar $resource, $create, $old_data = null
     dbg_error_log( 'PUT', 'Handling scheduling resources for %s on %s which is %s', $email,
                      ($create?'create':'update'), ($attendee_is_new? 'new' : 'an update') );
     if ( $schedule_target->Exists() ) {
-      $attendee_calendar = new WritableCollection(array('path' => $schedule_target->internal_url('schedule-default-calendar')));
+      // Instead of always writing to schedule-default-calendar, we first try to
+      // find a calendar with an existing instance of the event.
+      $sql = 'SELECT caldav_data.dav_name, caldav_data.caldav_data, caldav_data.collection_id FROM caldav_data JOIN calendar_item USING(dav_id) ';
+      $sql .= 'WHERE caldav_data.collection_id IN (SELECT collection_id FROM collection WHERE is_calendar AND user_no =?) ';
+      $sql .= 'AND uid=? LIMIT 1';
+      $qry = new AwlQuery($sql,$schedule_target->user_no(), $uid);
+      if ( !$qry->Exec('PUT',__LINE__,__FILE__) || $qry->rows() < 1 ) {
+        dbg_error_log( 'PUT', "Could not find event in attendee's calendars" );
+        $attendee_calendar = new WritableCollection(array('path' => $schedule_target->internal_url('schedule-default-calendar')));
+      } else {
+        $row = $qry->Fetch();
+        $r = new DAVResource($row);
+        $attendee_calendar = new WritableCollection(array('path' => $r->parent_path()));
+        if ($attendee_calendar->IsCalendar()) {
+          dbg_error_log( 'XXX', "found the event in attendee's calendar %s", $attendee_calendar->dav_name() );
+        } else {
+          dbg_error_log( 'XXX', 'could not find the event in any calendar, using schedule-default-calendar');
+          $attendee_calendar = new WritableCollection(array('path' => $schedule_target->internal_url('schedule-default-calendar')));
+        }
+      }
       if ( !$attendee_calendar->Exists() ) {
         dbg_error_log('ERROR','Default calendar at "%s" does not exist for user "%s"',
                       $attendee_calendar->dav_name(), $schedule_target->username());
@@ -532,6 +596,27 @@ function do_scheduling_requests( vCalendar $resource, $create, $old_data = null
         }
       }
     }
+    else {
+      $remote = new iSchedule ();
+      $answer = $remote->sendRequest ( $email, 'VEVENT/REQUEST', $schedule_request->Render() );
+      if ( $answer === false ) {
+        $response = "3.7;Invalid Calendar User" ;
+      }
+      else {
+        foreach ( $answer as $a ) // should only be one element in array
+        {
+          if ( $a === false ) {
+            $response = "3.7;Invalid Calendar User" ;
+          }
+          elseif ( substr( $a, 0, 1 ) >= 1 ) {
+            $response = $a ;
+          }
+          else {
+            $response = "2.0;Success" ;
+          }
+        }
+      }
+    }
     dbg_error_log( 'PUT', 'Status for attendee <%s> set to "%s"', $attendee->Value(), $response );
     $attendee->SetParameterValue( 'SCHEDULE-STATUS', $response );
     $scheduling_actions = true;
@@ -703,6 +788,7 @@ function import_calendar_collection( $ics_content, $user_no, $path, $caldav_cont
     $qry = new AwlQuery( $sql, array( ':displayname' => $displayname, ':dav_name' => $path) );
     if ( ! $qry->Exec('PUT',__LINE__,__FILE__) ) rollback_on_error( $caldav_context, $user_no, $path );
   }
+  
 
   $tz_ids    = array();
   foreach( $timezones AS $k => $tz ) {
@@ -737,20 +823,29 @@ function import_calendar_collection( $ics_content, $user_no, $path, $caldav_cont
     rollback_on_error( $caldav_context, $user_no, $path );
   }
   $collection = $qry->Fetch();
-
+  $collection_id = $collection->collection_id;
+  
+  // Fetch the current collection data
+  $qry->QDo('SELECT dav_name, caldav_data FROM caldav_data WHERE collection_id=:collection_id', array(
+          ':collection_id' => $collection_id
+      ));
+  $current_data = array();
+  while( $row = $qry->Fetch() )
+    $current_data[$row->dav_name] = $row->caldav_data;
+  
   if ( !(isset($c->skip_bad_event_on_import) && $c->skip_bad_event_on_import) ) $qry->Begin();
-  $base_params = array( ':collection_id' => $collection->collection_id );
-  if ( !$appending ) {
-    if ( !$qry->QDo('DELETE FROM calendar_item WHERE collection_id = :collection_id', $base_params)
-      || !$qry->QDo('DELETE FROM caldav_data WHERE collection_id = :collection_id', $base_params) )
-      rollback_on_error( $caldav_context, $user_no, $collection->collection_id );
-  }
+  $base_params = array( ':collection_id' => $collection_id );
 
   $dav_data_insert = <<<EOSQL
 INSERT INTO caldav_data ( user_no, dav_name, dav_etag, caldav_data, caldav_type, logged_user, created, modified, collection_id )
     VALUES( :user_no, :dav_name, :etag, :dav_data, :caldav_type, :session_user, current_timestamp, current_timestamp, :collection_id )
 EOSQL;
 
+  $dav_data_update = <<<EOSQL
+UPDATE caldav_data SET user_no=:user_no, caldav_data=:dav_data, dav_etag=:etag, caldav_type=:caldav_type, logged_user=:session_user,
+  modified=current_timestamp WHERE collection_id=:collection_id AND dav_name=:dav_name
+EOSQL;
+  
   $calitem_insert = <<<EOSQL
 INSERT INTO calendar_item (user_no, dav_name, dav_id, dav_etag, uid, dtstamp, dtstart, dtend, summary, location, class, transp,
                     description, rrule, tz_id, last_modified, url, priority, created, due, percent_complete, status, collection_id )
@@ -758,28 +853,57 @@ INSERT INTO calendar_item (user_no, dav_name, dav_id, dav_etag, uid, dtstamp, dt
                 :description, :rrule, :tzid, :modified, :url, :priority, :created, :due, :percent_complete, :status, :collection_id)
 EOSQL;
 
+  $calitem_update = <<<EOSQL
+UPDATE calendar_item SET user_no=:user_no, dav_etag=:etag, uid=:uid, dtstamp=:dtstamp,
+                dtstart=:dtstart, dtend=##dtend##, summary=:summary, location=:location,
+                class=:class, transp=:transp, description=:description, rrule=:rrule,
+                tz_id=:tzid, last_modified=:modified, url=:url, priority=:priority,
+                due=:due, percent_complete=:percent_complete, status=:status
+       WHERE collection_id=:collection_id AND dav_name=:dav_name
+EOSQL;
+  
   $last_olson = '';
+  if ( count($resources) > 0 )
+    $qry->QDo('SELECT new_sync_token(0,'.$collection_id.')');
+  
   foreach( $resources AS $uid => $resource ) {
-    if ( isset($c->skip_bad_event_on_import) && $c->skip_bad_event_on_import ) $qry->Begin();
 
     /** Construct the VCALENDAR data */
     $vcal = new vCalendar();
     $vcal->SetComponents($resource);
     $icalendar = $vcal->Render();
+    $dav_name = sprintf( '%s%s.ics', $path, preg_replace('{[&?\\/@%+:]}','',$uid) );
 
+    /** Do we need to do anything? */
+    $inserting = true;
+    if ( isset($current_data[$dav_name]) ) {
+      if ( $icalendar == $current_data[$dav_name] ) {
+        unset($current_data[$dav_name]);
+        continue;
+      }
+      $sync_change = 200;
+      unset($current_data[$dav_name]);
+      $inserting = false;
+    }
+    else
+      $sync_change = 201;
+    
+    if ( isset($c->skip_bad_event_on_import) && $c->skip_bad_event_on_import ) $qry->Begin();
+    
     /** As ever, we mostly deal with the first resource component */
     $first = $resource[0];
 
     $dav_data_params = $base_params;
     $dav_data_params[':user_no'] = $user_no;
     // We don't allow any of &?\/@%+: in the UID to appear in the path, but anything else is fair game.
-    $dav_data_params[':dav_name'] = sprintf( '%s%s.ics', $path, preg_replace('{[&?\\/@%+:]}','',$uid) );
+    $dav_data_params[':dav_name'] = $dav_name;
     $dav_data_params[':etag'] = md5($icalendar);
     $calitem_params = $dav_data_params;
     $dav_data_params[':dav_data'] = $icalendar;
     $dav_data_params[':caldav_type'] = $first->GetType();
     $dav_data_params[':session_user'] = $session->user_no;
-    if ( !$qry->QDo($dav_data_insert,$dav_data_params) ) rollback_on_error( $caldav_context, $user_no, $path );
+    if ( !$qry->QDo( ($inserting ? $dav_data_insert : $dav_data_update), $dav_data_params) )
+      rollback_on_error( $caldav_context, $user_no, $path );
 
     $qry->QDo('SELECT dav_id FROM caldav_data WHERE dav_name = :dav_name ', array(':dav_name' => $dav_data_params[':dav_name']));
     if ( $qry->rows() == 1 && $row = $qry->Fetch() ) {
@@ -821,6 +945,10 @@ EOSQL;
         *
         */
         $dtstart_prop = $first->GetProperty('DTSTART');
+        if ( empty($dtstart_prop) ) {
+          dbg_error_log('PUT','Invalid VEVENT without DTSTART, UID="%s" in collection %d', $uid, $collection_id);
+          continue;
+        } 
         $value_type = $dtstart_prop->GetParameterValue('VALUE');
         dbg_error_log('PUT','DTSTART without DTEND. DTSTART value type is %s', $value_type );
         if ( isset($value_type) && $value_type == 'DATE' )
@@ -871,7 +999,7 @@ EOSQL;
       $tz = $olson = $tzid = null;
     }
 
-    $sql = str_replace( '##dtend##', $dtend, $calitem_insert );
+    $sql = str_replace( '##dtend##', $dtend, ($inserting ? $calitem_insert : $calitem_update) );
     $calitem_params[':tzid'] = $tzid;
     $calitem_params[':uid'] = $first->GetPValue('UID');
     $calitem_params[':summary'] = $first->GetPValue('SUMMARY');
@@ -885,19 +1013,34 @@ EOSQL;
     $calitem_params[':percent_complete'] = $first->GetPValue('PERCENT-COMPLETE');
     $calitem_params[':status'] = $first->GetPValue('STATUS');
 
-    $created = $first->GetPValue('CREATED');
-    if ( $created == '00001231T000000Z' ) $created = '20001231T000000Z';
-    $calitem_params[':created'] = $created;
+    if ( $inserting ) {
+      $created = $first->GetPValue('CREATED');
+      if ( $created == '00001231T000000Z' ) $created = '20001231T000000Z';
+      $calitem_params[':created'] = $created;
+    }
 
     if ( !$qry->QDo($sql,$calitem_params) ) rollback_on_error( $caldav_context, $user_no, $path);
 
     write_alarms($dav_id, $first);
     write_attendees($dav_id, $vcal);
 
+    $qry->QDo("SELECT write_sync_change( $collection_id, $sync_change, :dav_name)", array(':dav_name' => $dav_name ) );
+    
     do_scheduling_requests( $vcal, true );
     if ( isset($c->skip_bad_event_on_import) && $c->skip_bad_event_on_import ) $qry->Commit();
   }
 
+  if ( !$appending && count($current_data) > 0 ) {
+    $params = array( ':collection_id' => $collection_id );
+    if ( isset($c->skip_bad_event_on_import) && $c->skip_bad_event_on_import ) $qry->Begin();
+    foreach( $current_data AS $dav_name => $data ) {
+      $params[':dav_name'] = $dav_name;
+      $qry->QDo('DELETE FROM caldav_data WHERE collection_id = :collection_id AND dav_name = :dav_name', $params);
+      $qry->QDo('SELECT write_sync_change(:collection_id, 404, :dav_name)', $params);
+    }
+    if ( isset($c->skip_bad_event_on_import) && $c->skip_bad_event_on_import ) $qry->Commit();
+  }
+  
   if ( !(isset($c->skip_bad_event_on_import) && $c->skip_bad_event_on_import) ) {
     if ( ! $qry->Commit() ) rollback_on_error( $caldav_context, $user_no, $path);
   }
@@ -932,9 +1075,9 @@ function write_alarms( $dav_id, vComponent $ical ) {
     $trigger_type = $trigger->GetParameterValue('VALUE');
     if ( !isset($trigger_type) || $trigger_type == 'DURATION' ) {
       switch ( $trigger->GetParameterValue('RELATED') ) {
-        case 'DTEND':  $related = $ical->GetPValue('DTEND'); break;
-        case 'DUE':    $related = $ical->GetPValue('DUE');   break;
-        default:       $related = $ical->GetPValue('DTSTART');
+        case 'DTEND':  $related = $ical->GetProperty('DTEND'); break;
+        case 'DUE':    $related = $ical->GetProperty('DUE');   break;
+        default:       $related = $ical->GetProperty('DTSTART');
       }
       $duration = $trigger->Value();
       if ( !preg_match('{^-?P(:?\d+W)?(:?\d+D)?(:?T(:?\d+H)?(:?\d+M)?(:?\d+S)?)?$}', $duration ) ) continue;
@@ -947,15 +1090,20 @@ function write_alarms( $dav_id, vComponent $ical ) {
         $related_trigger = preg_replace( '{(\d+[WDHMS])}', '$1 ', $related_trigger );
       }
     }
+    else if ( $trigger_type == 'DATE-TIME' ) {
+      $related = $trigger;
+    }
     else {
       if ( false === strtotime($trigger->Value()) ) continue; // Invalid date.
+      $related = $trigger;
     }
+    $related_date = new RepeatRuleDateTime($related);
     $qry->Bind(':action', $v->GetPValue('ACTION'));
     $qry->Bind(':trigger', $trigger->Render());
     $qry->Bind(':summary', $v->GetPValue('SUMMARY'));
     $qry->Bind(':description', $v->GetPValue('DESCRIPTION'));
     $qry->Bind(':component', $v->Render());
-    $qry->Bind(':related', $related );
+    $qry->Bind(':related', $related_date->UTC() );
     $qry->Bind(':related_trigger', $related_trigger );
     $qry->Exec('PUT',__LINE__,__FILE__);
   }
@@ -1193,6 +1341,7 @@ function write_resource( DAVResource $resource, $caldav_data, DAVResource $colle
 
   }
 
+  $qry->QDo('SELECT new_sync_token(0,'.$collection_id.')');
 
   $calitem_params[':tzid'] = $tzid;
   $calitem_params[':uid'] = $first->GetPValue('UID');
@@ -1282,6 +1431,10 @@ EOSQL;
   $qry->QDo("SELECT write_sync_change( $collection_id, $sync_change, :dav_name)", array(':dav_name' => $path ) );
   $qry->Commit();
 
+  if ( function_exists('post_commit_action') ) {
+    post_commit_action( $put_action_type, $first->GetPValue('UID'), $user_no, $collection_id, $path );
+  }
+  
   // Uncache anything to do with the collection
   $cache = getCacheInstance();
   $cache_ns = 'collection-'.preg_replace( '{/[^/]*$}', '/', $path);
