@@ -14,19 +14,34 @@ $responses = array();
 /**
  * Build the array of properties to include in the report output
  */
+$sync_level = $xmltree->GetPath('/DAV::sync-collection/DAV::sync-level');
+if ( empty($sync_level) ) {
+  $sync_level = $request->depth;
+}
+else {
+  $sync_level = $sync_level[0]->GetContent();
+  if ( $sync_level == 'infinity' )
+    $sync_level = DEPTH_INFINITY;
+  else
+    $sync_level = 1;
+}
+
+if ( $sync_level == DEPTH_INFINITY ) {
+  $request->PreconditionFailed(403, 'DAV::sync-traversal-supported','This server does not support sync-traversal');
+}
+
 $sync_tokens = $xmltree->GetPath('/DAV::sync-collection/DAV::sync-token');
 $sync_token = $sync_tokens[0]->GetContent();
 if ( !isset($sync_token) ) $sync_token = 0;
 $sync_token = intval(str_ireplace('data:,', '', $sync_token ));
 dbg_error_log( 'sync', " sync-token: %s", $sync_token );
 
-
-$props = $xmltree->GetElements('DAV::prop');
-$v = $props[0];
-$props = $v->GetContent();
 $proplist = array();
-foreach( $props AS $k => $v ) {
-  $proplist[] = $v->GetTag();
+$props = $xmltree->GetPath('/DAV::sync-collection/DAV::prop/*');
+if ( !empty($props) ) {
+  foreach( $props AS $k => $v ) {
+    $proplist[] = $v->GetNSTag();
+  }
 }
 
 function display_status( $status_code ) {
@@ -37,7 +52,10 @@ $collection = new DAVResource( $request->path );
 if ( !$collection->Exists() ) {
   $request->DoResponse( 404 );
 }
-  
+$bound_from = $collection->bound_from();
+$collection_path = $collection->dav_name();
+$request_via_binding = ($bound_from != $collection_path);
+
 $params = array( ':collection_id' => $collection->GetProperty('collection_id'), ':sync_token' => $sync_token );
 $sql = "SELECT new_sync_token( :sync_token, :collection_id)";
 $qry = new AwlQuery($sql, $params);
@@ -62,13 +80,17 @@ if ( $sync_token == $new_token ) {
   $responses[] = new XMLElement( 'sync-token', 'data:,'.$new_token );
 }
 else {
+  $hide_older = '';
+  if ( isset($c->hide_older_than) && intval($c->hide_older_than) > 0 )
+    $hide_older = " AND (CASE WHEN caldav_data.caldav_type<>'VEVENT' OR calendar_item.dtstart IS NULL THEN true ELSE calendar_item.dtstart > (now() - interval '".intval($c->hide_older_than)." days') END)";
+
   if ( $sync_token == 0 ) {
     $sql = <<<EOSQL
   SELECT collection.*, calendar_item.*, caldav_data.*, addressbook_resource.*, 201 AS sync_status FROM collection
               LEFT JOIN caldav_data USING (collection_id)
               LEFT JOIN calendar_item USING (dav_id)
                            LEFT JOIN addressbook_resource USING (dav_id)
-              WHERE collection.collection_id = :collection_id
+              WHERE collection.collection_id = :collection_id $hide_older
      ORDER BY collection.collection_id, caldav_data.dav_id
 EOSQL;
     unset($params[':sync_token']);
@@ -80,10 +102,15 @@ EOSQL;
                            LEFT JOIN caldav_data USING (collection_id,dav_id)
                            LEFT JOIN calendar_item USING (collection_id,dav_id)
                            LEFT JOIN addressbook_resource USING (dav_id)
-                           WHERE collection.collection_id = :collection_id
-         AND sync_time > (SELECT modification_time FROM sync_tokens WHERE sync_token = :sync_token)
-     ORDER BY collection.collection_id, sync_changes.dav_name, sync_changes.sync_time
+                           WHERE collection.collection_id = :collection_id $hide_older
+         AND sync_time >= (SELECT modification_time FROM sync_tokens WHERE sync_token = :sync_token)
 EOSQL;
+    if ( isset($c->strict_result_ordering) && $c->strict_result_ordering ) {
+      $sql .= " ORDER BY collection.collection_id, lower(sync_changes.dav_name), sync_changes.sync_time";
+    }
+    else {
+      $sql .= " ORDER BY collection.collection_id, sync_changes.dav_name, sync_changes.sync_time";
+    }
   }
   $qry = new AwlQuery($sql, $params );
  
@@ -96,6 +123,9 @@ EOSQL;
       $c->sync_resource_data_ok = false;
     }
     while( $object = $qry->Fetch() ) {
+      if ( $request_via_binding )
+        $object->dav_name = str_replace( $bound_from, $collection_path, $object->dav_name);
+
       if ( $object->dav_name == $last_dav_name ) {
         /** The complex case: this is the second or subsequent for this dav_id */
         if ( $object->sync_status == 404 ) {
@@ -104,7 +134,7 @@ EOSQL;
             new XMLElement( 'href', ConstructURL($object->dav_name) ),
             new XMLElement( 'status', display_status($object->sync_status) )
           );
-          $responses[] = new XMLElement( 'sync-response', $resultset );
+          $responses[] = new XMLElement( 'response', $resultset );
           $first_status = 404;
         }
         else if ( $object->sync_status == 201 && $first_status == 404 ) {
