@@ -34,8 +34,8 @@ if ( !is_object($xmltree) ) {
 
 $target = new DAVResource($request->path);
 
-if ( $xmltree->GetTag() != 'DAV::principal-property-search'
-                && $xmltree->GetTag() != 'DAV::principal-property-search-set' ) {
+if ( $xmltree->GetNSTag() != 'DAV::principal-property-search'
+                && $xmltree->GetNSTag() != 'DAV::principal-property-search-set' ) {
   $target->NeedPrivilege( array('DAV::read', 'urn:ietf:params:xml:ns:caldav:read-free-busy'), true ); // They may have either
 }
 
@@ -47,13 +47,13 @@ $denied = array();
 $unsupported = array();
 if ( isset($prop_filter) ) unset($prop_filter);
 
-if ( $xmltree->GetTag() == 'urn:ietf:params:xml:ns:caldav:free-busy-query' ) {
+if ( $xmltree->GetNSTag() == 'urn:ietf:params:xml:ns:caldav:free-busy-query' ) {
   include("caldav-REPORT-freebusy.php");
   exit; // Not that the above include should return anyway
 }
 
 $reply = new XMLDocument( array( "DAV:" => "" ) );
-switch( $xmltree->GetTag() ) {
+switch( $xmltree->GetNSTag() ) {
   case 'DAV::principal-property-search':
     include("caldav-REPORT-principal.php");
     exit; // Not that it should return anyway.
@@ -129,7 +129,7 @@ function component_to_xml( $properties, $item ) {
     }
 
     if ( isset($c->hide_alarm) && $c->hide_alarm ) {
-      $dav_resource = new DAVResource($request->path);
+      $dav_resource = new DAVResource($item->dav_name);
       if ( isset($properties['calendar-data']) && !$dav_resource->HavePrivilegeTo('write') ) {
         dbg_error_log("REPORT","Stripping event alarms for: %s", $item->dav_name );
         $vcal = new vCalendar($caldav_data);
@@ -142,71 +142,76 @@ function component_to_xml( $properties, $item ) {
   $url = ConstructURL($item->dav_name);
 
   $prop = new XMLElement("prop");
-  foreach( $properties AS $k => $v ) {
-    switch( $k ) {
-      case 'getcontentlength':
+  $need_resource = false;
+  foreach( $properties AS $full_tag => $v ) {
+    $base_tag = preg_replace('{^.*:}', '', $full_tag );
+    switch( $full_tag ) {
+      case 'DAV::getcontentlength':
         $contentlength = strlen($caldav_data);
-        $prop->NewElement($k, $contentlength );
+        $prop->NewElement($base_tag, $contentlength );
         break;
-      case 'getlastmodified':
-        $prop->NewElement($k, ISODateToHTTPDate($item->modified) );
+      case 'DAV::getlastmodified':
+        $prop->NewElement($base_tag, ISODateToHTTPDate($item->modified) );
         break;
-      case 'calendar-data':
-        if ( $type == 'calendar' ) $reply->CalDAVElement($prop, $k, $caldav_data );
-        else $unsupported[] = $k;
+      case 'urn:ietf:params:xml:ns:caldav:calendar-data':
+        if ( $type == 'calendar' ) $reply->CalDAVElement($prop, $base_tag, $caldav_data );
+        else $unsupported[] = $base_tag;
         break;
-      case 'address-data':
-        if ( $type == 'vcard' ) $reply->CardDAVElement($prop, $k, $caldav_data );
-        else $unsupported[] = $k;
+      case 'urn:ietf:params:xml:ns:carddav:address-data':
+        if ( $type == 'vcard' ) $reply->CardDAVElement($prop, $base_tag, $caldav_data );
+        else $unsupported[] = $base_tag;
         break;
-      case 'getcontenttype':
-        $prop->NewElement($k, $contenttype );
+      case 'DAV::getcontenttype':
+        $prop->NewElement($base_tag, $contenttype );
         break;
-      case 'current-user-principal':
+      case 'DAV::current-user-principal':
         $prop->NewElement("current-user-principal", $request->current_user_principal_xml);
         break;
-      case 'displayname':
-        $prop->NewElement($k, $displayname );
+      case 'DAV::displayname':
+        $prop->NewElement($base_tag, $displayname );
         break;
-      case 'resourcetype':
-        $prop->NewElement($k); // Just an empty resourcetype for a non-collection.
+      case 'DAV::resourcetype':
+        $prop->NewElement($base_tag); // Just an empty resourcetype for a non-collection.
         break;
-      case 'getetag':
-        $prop->NewElement($k, '"'.$item->dav_etag.'"' );
+      case 'DAV::getetag':
+        $prop->NewElement($base_tag, '"'.$item->dav_etag.'"' );
         break;
       case '"current-user-privilege-set"':
-        $prop->NewElement($k, privileges($request->permissions) );
-        break;
-      case 'SOME-DENIED-PROPERTY':  /** indicating the style for future expansion */
-        $denied[] = $k;
+        $prop->NewElement($base_tag, privileges($request->permissions) );
         break;
       default:
-        dbg_error_log( 'REPORT', "Request for unsupported property '%s' of calendar item.", $v );
-        $unsupported[] = $k;
+        // It's harder.  We need the DAVResource() to get this one.
+        $need_resource = true;
     }
+    if ( $need_resource ) break;
   }
-  $status = new XMLElement("status", "HTTP/1.1 200 OK" );
-
-  $propstat = new XMLElement( "propstat", array( $prop, $status) );
   $href = new XMLElement("href", $url );
-  $elements = array($href,$propstat);
-
-  if ( count($denied) > 0 ) {
-    $status = new XMLElement("status", "HTTP/1.1 403 Forbidden" );
-    $noprop = new XMLElement("prop");
-    foreach( $denied AS $k => $v ) {
-      $noprop->NewElement( strtolower($v) );
-    }
-    $elements[] = new XMLElement( "propstat", array( $noprop, $status) );
+  if ( $need_resource ) {
+    if ( !isset($dav_resource) ) $dav_resource = new DAVResource($item->dav_name);
+    $elements = $dav_resource->GetPropStat(array_keys($properties), $reply);
+    array_unshift($elements, $href);
   }
-
-  if ( count($unsupported) > 0 ) {
-    $status = new XMLElement("status", "HTTP/1.1 404 Not Found" );
-    $noprop = new XMLElement("prop");
-    foreach( $unsupported AS $k => $v ) {
-      $noprop->NewElement( strtolower($v) );
+  else {
+    $elements = array($href);
+    $status = new XMLElement("status", "HTTP/1.1 200 OK" );
+    $elements[] = new XMLElement( "propstat", array( $prop, $status) );
+    if ( count($denied) > 0 ) {
+      $status = new XMLElement("status", "HTTP/1.1 403 Forbidden" );
+      $noprop = new XMLElement("prop");
+      foreach( $denied AS $k => $v ) {
+        $reply->NSElement($noprop, $v);
+      }
+      $elements[] = new XMLElement( "propstat", array( $noprop, $status) );
+    }
+  
+    if ( ! $request->PreferMinimal() && count($unsupported) > 0 ) {
+      $status = new XMLElement("status", "HTTP/1.1 404 Not Found" );
+      $noprop = new XMLElement("prop");
+      foreach( $unsupported AS $k => $v ) {
+        $reply->NSElement($noprop, $v);
+      }
+      $elements[] = new XMLElement( "propstat", array( $noprop, $status) );
     }
-    $elements[] = new XMLElement( "propstat", array( $noprop, $status) );
   }
 
   $response = new XMLElement( "response", $elements );
@@ -219,26 +224,29 @@ if ( $target->IsExternal() ) {
 	update_external ( $target );
 }
 
-if ( $xmltree->GetTag() == "urn:ietf:params:xml:ns:caldav:calendar-query" ) {
+// These reports are always allowed to see the resource_data because they are special
+$c->sync_resource_data_ok = true;
+
+if ( $xmltree->GetNSTag() == "urn:ietf:params:xml:ns:caldav:calendar-query" ) {
   $calquery = $xmltree->GetPath("/urn:ietf:params:xml:ns:caldav:calendar-query/*");
   include("caldav-REPORT-calquery.php");
 }
-elseif ( $xmltree->GetTag() == "urn:ietf:params:xml:ns:caldav:calendar-multiget" ) {
+elseif ( $xmltree->GetNSTag() == "urn:ietf:params:xml:ns:caldav:calendar-multiget" ) {
   $mode = 'caldav';
   $qry_content = $xmltree->GetContent('urn:ietf:params:xml:ns:caldav:calendar-multiget');
   include("caldav-REPORT-multiget.php");
 }
-elseif ( $xmltree->GetTag() == "urn:ietf:params:xml:ns:carddav:addressbook-multiget" ) {
+elseif ( $xmltree->GetNSTag() == "urn:ietf:params:xml:ns:carddav:addressbook-multiget" ) {
   $mode = 'carddav';
   $qry_content = $xmltree->GetContent('urn:ietf:params:xml:ns:carddav:addressbook-multiget');
   include("caldav-REPORT-multiget.php");
 }
-elseif ( $xmltree->GetTag() == "urn:ietf:params:xml:ns:carddav:addressbook-query" ) {
+elseif ( $xmltree->GetNSTag() == "urn:ietf:params:xml:ns:carddav:addressbook-query" ) {
   $cardquery = $xmltree->GetPath("/urn:ietf:params:xml:ns:carddav:addressbook-query/*");
   include("caldav-REPORT-cardquery.php");
 }
 else {
-  dbg_error_log( 'ERROR', "Request for unsupported report type '%s'.", $xmltree->GetTag() );
-  $request->PreconditionFailed( 403, 'DAV::supported-report', sprintf( '"%s" is not a supported report type', $xmltree->GetTag()) );
+  dbg_error_log( 'ERROR', "Request for unsupported report type '%s'.", $xmltree->GetNSTag() );
+  $request->PreconditionFailed( 403, 'DAV::supported-report', sprintf( '"%s" is not a supported report type', $xmltree->GetNSTag()) );
 }
 
