@@ -205,25 +205,25 @@ class ldapDrivers
     $dnUser = ldap_get_dn($this->connect, ldap_first_entry($this->connect,$entry));
 
     if ( isset($c->authenticate_hook['config']['i_use_mode_kerberos']) && $c->authenticate_hook['config']['i_use_mode_kerberos'] == "i_know_what_i_am_doing") {
-    	dbg_error_log( "LOG", "drivers_ldap : Skipping password Check for user %s which should be the same as %s",$username , $_SERVER["REMOTE_USER"]);
+    	dbg_error_log( "LDAP", "drivers_ldap : Skipping password Check for user %s which should be the same as %s",$username , $_SERVER["REMOTE_USER"]);
       if ($username != $_SERVER["REMOTE_USER"]) {
         return false;
       }
     }
     else if ( empty($passwd) || preg_match('/[\x00-\x19]/',$passwd) ) {
       // See http://www.php.net/manual/en/function.ldap-bind.php#73718 for more background
-      dbg_error_log( 'LDAP', 'drivers_ldap : user %s supplied empty or invalid password (%s): login rejected', $dnUser, $passwd );
+      dbg_error_log( 'LDAP', 'drivers_ldap : user %s supplied empty or invalid password: login rejected', $dnUser );
       return false;
     }
     else {
       if ( !@ldap_bind($this->connect, $dnUser, $passwd) ) {
-        dbg_error_log( "LDAP", "drivers_ldap : Failed to bind to user %s using password %s", $dnUser, $passwd );
+        dbg_error_log( "LDAP", "drivers_ldap : Failed to bind to user %s ", $dnUser );
         return false;
       }
     }
 
-
-    dbg_error_log( "LDAP", "drivers_ldap : Bound to user %s using password %s", $dnUser, $passwd );
+    dbg_error_log( "LDAP", "drivers_ldap : Bound to user %s using password %s", $dnUser,
+          (isset($c->dbg['password']) && $c->dbg['password'] ? $passwd : 'another delicious password for the debugging monster!') );
 
     $i = ldap_first_entry($this->connect,$entry);
     $arr = ldap_get_attributes($this->connect,$i);
@@ -263,20 +263,20 @@ function sync_user_from_LDAP( Principal &$principal, $mapping, $ldap_values ) {
 
   $fields_to_set = array();
   $updateable_fields = Principal::updateableFields();
-  if ( isset($mapping['active']) && !isset($mapping['user_active']) ) {
-    // Backward compatibility: now 'user_active'
-    $mapping['user_active'] = $mapping['active'];
-    unset($mapping['active']);
-  }
-  if ( isset($mapping['updated']) && !isset($mapping['modified']) ) {
-    // Backward compatibility: now 'modified'
-    $mapping['modified'] = $mapping['updated'];
-    unset($mapping['updated']);
-  }
   foreach( $updateable_fields AS $field ) {
-    if ( isset($mapping[$field]) && isset($ldap_values[$mapping[$field]]) ) {
-      $fields_to_set[$field] = $ldap_values[$mapping[$field]];
-      dbg_error_log( "LDAP", "Setting usr->%s to %s from LDAP field %s", $field, $ldap_values[$mapping[$field]], $mapping[$field] );
+    if ( isset($mapping[$field]) ) {
+      $tab_part_fields = explode(',',$mapping[$field]);
+      foreach( $tab_part_fields as $part_field ) {
+        if ( isset($ldap_values[$part_field]) ) {
+          if (isset($fields_to_set[$field]) ) {
+            $fields_to_set[$field] .= ' '.$ldap_values[$part_field];
+          }
+          else {
+            $fields_to_set[$field] = $ldap_values[$part_field];
+          }
+        }
+      }
+      dbg_error_log( "LDAP", "Setting usr->%s to %s from LDAP field %s", $field, $fields_to_set[$field], $mapping[$field] );
     }
     else if ( isset($c->authenticate_hook['config']['default_value']) && is_array($c->authenticate_hook['config']['default_value'])
               && isset($c->authenticate_hook['config']['default_value'][$field] ) ) {
@@ -295,6 +295,19 @@ function sync_user_from_LDAP( Principal &$principal, $mapping, $ldap_values ) {
   }
 }
 
+/*
+* explode the multipart mapping
+*/
+function array_values_mapping($mapping){
+  $attributes=array();
+  foreach ( $mapping as $field ) {
+    $tab_part_field = explode(",",$field);
+    foreach( $tab_part_field as $part_field ) {
+      $attributes[] = $part_field;
+    }
+  }
+  return $attributes;
+}
 
 /**
 * Check the username / password against the LDAP server
@@ -304,12 +317,27 @@ function LDAP_check($username, $password ){
 
   $ldapDriver = getStaticLdap();
   if ( !$ldapDriver->valid ) {
-    dbg_error_log( "ERROR", "Couldn't contact LDAP server for authentication" );
-    return false;
+    sleep(1);  // Sleep very briefly to try and survive intermittent issues
+    $ldapDriver = getStaticLdap();
+    if ( !$ldapDriver->valid ) {
+      dbg_error_log( "ERROR", "Couldn't contact LDAP server for authentication" );
+      header( sprintf("HTTP/1.1 %d %s", 503, translate("Authentication server unavailable.")) );
+      exit(0);
+    }
   }
 
   $mapping = $c->authenticate_hook['config']['mapping_field'];
-  $attributes = array_values($mapping);
+  if ( isset($mapping['active']) && !isset($mapping['user_active']) ) {
+    // Backward compatibility: now 'user_active'
+    $mapping['user_active'] = $mapping['active'];
+    unset($mapping['active']);
+  }
+  if ( isset($mapping['updated']) && !isset($mapping['modified']) ) {
+    // Backward compatibility: now 'modified'
+    $mapping['modified'] = $mapping['updated'];
+    unset($mapping['updated']);
+  }
+  $attributes = array_values_mapping($mapping);
 
   /**
   * If the config contains a filter that starts with a ( then believe
@@ -323,7 +351,7 @@ function LDAP_check($username, $password ){
     $filter_munge = "($ldapDriver->filterUsers)";
   }
 
-  $filter = "(&$filter_munge(".$mapping["username"]."=$username))";
+  $filter = "(&$filter_munge(".$mapping['username']."=$username))";
   $valid = $ldapDriver->requestUser( $filter, $attributes, $username, $password );
 
   // is a valid user or not
@@ -332,7 +360,7 @@ function LDAP_check($username, $password ){
     return false;
   }
 
-  $ldap_timestamp = $valid[$mapping["updated"]];
+  $ldap_timestamp = $valid[$mapping['modified']];
 
   /**
   * This splits the LDAP timestamp apart and assigns values to $Y $m $d $H $M and $S
@@ -341,7 +369,7 @@ function LDAP_check($username, $password ){
     $$k = substr($ldap_timestamp,$v[0],$v[1]);
 
   $ldap_timestamp = "$Y"."$m"."$d"."$H"."$M"."$S";
-  $valid[$mapping["updated"]] = "$Y-$m-$d $H:$M:$S";
+  $valid[$mapping['modified']] = "$Y-$m-$d $H:$M:$S";
 
   $principal = new Principal('username',$username);
   if ( $principal->Exists() ) {
@@ -375,7 +403,7 @@ function sync_LDAP_groups(){
 
   $mapping = $c->authenticate_hook['config']['group_mapping_field'];
   //$attributes = array('cn','modifyTimestamp','memberUid');
-  $attributes = array_values($mapping);
+  $attributes = array_values_mapping($mapping);
   $ldap_groups_tmp = $ldapDriver->getAllGroups($attributes);
 
   if ( sizeof($ldap_groups_tmp) == 0 ) return;
@@ -508,13 +536,13 @@ function sync_LDAP(){
   if ( ! $ldapDriver->valid ) return;
 
   $mapping = $c->authenticate_hook['config']['mapping_field'];
-  $attributes = array_values($mapping);
+  $attributes = array_values_mapping($mapping);
   $ldap_users_tmp = $ldapDriver->getAllUsers($attributes);
 
   if ( sizeof($ldap_users_tmp) == 0 ) return;
 
   foreach($ldap_users_tmp as $key => $ldap_user){
-    $ldap_users_info[$ldap_user[$mapping["username"]]] = $ldap_user;
+    $ldap_users_info[$ldap_user[$mapping['username']]] = $ldap_user;
     unset($ldap_users_tmp[$key]);
   }
   $qry = new AwlQuery( "SELECT username, user_no, modified as updated FROM dav_principal where type_id=1");
@@ -540,15 +568,23 @@ function sync_LDAP(){
     foreach( $users_to_create as $username ) {
       $principal = new Principal( 'username', $username );
       $valid = $ldap_users_info[$username];
-      $ldap_timestamp = $valid[$mapping['updated']];
+      $ldap_timestamp = $valid[$mapping['modified']];
 
-      /**
-      * This splits the LDAP timestamp apart and assigns values to $Y $m $d $H $M and $S
-      */
-      foreach($c->authenticate_hook['config']['format_updated'] as $k => $v)
-          $$k = substr($ldap_timestamp,$v[0],$v[1]);
-      $ldap_timestamp = $Y.$m.$d.$H.$M.$S;
-      $valid[$mapping["updated"]] = "$Y-$m-$d $H:$M:$S";
+      if ( !empty($c->authenticate_hook['config']['format_updated']) ) {
+        /**
+        * This splits the LDAP timestamp apart and assigns values to $Y $m $d $H $M and $S
+        */
+        foreach($c->authenticate_hook['config']['format_updated'] as $k => $v)
+            $$k = substr($ldap_timestamp,$v[0],$v[1]);
+        $ldap_timestamp = $Y.$m.$d.$H.$M.$S;
+      }
+      else if ( preg_match('{^(\d{8})(\d{6})(Z)?$', $ldap_timestamp, $matches ) ) {
+        $ldap_timestamp = $matches[1].'T'.$matches[2].$matches[3];
+      }
+      else if ( empty($ldap_timestamp) ) {
+        $ldap_timestamp = date('c');
+      }
+      $valid[$mapping['modified']] = $ldap_timestamp;
 
       sync_user_from_LDAP( $principal, $mapping, $valid );
     }
@@ -557,16 +593,19 @@ function sync_LDAP(){
   // deactivating all users
   $params = array();
   $i = 0;
+  $paramstring = '';
   foreach( $users_to_deactivate AS $v ) {
     if ( isset($c->do_not_sync_from_ldap) && isset($c->do_not_sync_from_ldap[$v]) ) continue;
+    if ( $i > 0 ) $paramstring .= ',';
+    $paramstring .= ':u'.$i.'::text';
     $params[':u'.$i++] = strtolower($v);
   }
   if ( count($params) > 0 ) {
     $c->messages[] = sprintf(i18n('- deactivating users : %s'),join(', ',$users_to_deactivate));
-    $qry = new AwlQuery( 'UPDATE usr SET active = FALSE WHERE lower(username) IN ('.implode(',',array_keys($params)).')', $params);
+    $qry = new AwlQuery( 'UPDATE usr SET active = FALSE WHERE lower(username) IN ('.$paramstring.')', $params);
     $qry->Exec('sync_LDAP',__LINE__,__FILE__);
 
-    Principal::cacheFlush('lower(username) IN ('.implode(',',array_keys($params)).')', $params);
+    Principal::cacheFlush('lower(username) IN ('.$paramstring.')', $params);
   }
 
   // updating all users
@@ -574,7 +613,7 @@ function sync_LDAP(){
     foreach ( $users_to_update as $key=> $username ) {
       $principal = new Principal( 'username', $username );
       $valid=$ldap_users_info[$username];
-      $ldap_timestamp = $valid[$mapping['updated']];
+      $ldap_timestamp = $valid[$mapping['modified']];
 
       $valid['user_no'] = $db_users_info[$username]['user_no'];
       $mapping['user_no'] = 'user_no';
@@ -586,7 +625,7 @@ function sync_LDAP(){
         $$k = substr($ldap_timestamp,$v[0],$v[1]);
       }
       $ldap_timestamp = $Y.$m.$d.$H.$M.$S;
-      $valid[$mapping['updated']] = "$Y-$m-$d $H:$M:$S";
+      $valid[$mapping['modified']] = "$Y-$m-$d $H:$M:$S";
 
       $db_timestamp = substr(strtr($db_users_info[$username]['updated'], array(':' => '',' '=>'','-'=>'')),0,14);
       if ( $ldap_timestamp > $db_timestamp ) {
