@@ -16,7 +16,7 @@ $editor->AddAttribute('timezone', 'id', 'fld_timezone' );
 $editor->AddAttribute('schedule_transp', 'id', 'fld_schedule_transp' );
 $editor->AddAttribute('is_calendar', 'id', 'fld_is_calendar');
 $editor->AddAttribute('is_addressbook', 'id', 'fld_is_addressbook');
-$editor->AddAttribute('is_calendar', 'onclick', 'toggle_enabled(\'fld_is_calendar\',\'=fld_timezone\',\'=fld_schedule_transp\',\'!fld_is_addressbook\',\'=fld_ics_file\');');
+$editor->AddAttribute('is_calendar', 'onclick', 'toggle_enabled(\'fld_is_calendar\',\'=fld_timezone\',\'=fld_schedule_transp\',\'!fld_is_addressbook\');');
 $editor->AddAttribute('is_addressbook', 'onclick', 'toggle_enabled(\'fld_is_addressbook\',\'!fld_is_calendar\');');
 
 $editor->AddField('use_default_privs','default_privileges IS NULL');
@@ -24,8 +24,12 @@ $editor->AddAttribute('use_default_privs', 'id', 'fld_use_default_privs');
 $editor->AddAttribute('use_default_privs', 'onclick', 'toggle_visible(\'fld_use_default_privs\',\'!privileges_settings\');');
 
 $editor->AddField('ics_file', "''");
-$editor->AddAttribute('ics_file', 'title', translate('Upload a .ics calendar in iCalendar format to initialise or replace this calendar.'));
+$editor->AddAttribute('ics_file', 'title', translate('Upload an iCalendar file or VCard file to replace this collection.'));
 $editor->AddAttribute('ics_file', 'id', 'fld_ics_file');
+$editor->AddField('mode', 'FALSE');
+$editor->AddAttribute('mode', 'title', translate('Should the uploaded entries be appended to the collection?'));
+$editor->AddAttribute('mode', '_label', translate('Append'));
+$editor->AddAttribute('mode', 'id', 'fld_mode');
 
 $editor->SetWhere( 'collection_id='.$id );
 
@@ -108,9 +112,10 @@ if ( $can_write_collection && $editor->IsSubmit() ) {
       $path = $editor->Value('dav_name');
       $user_no = $editor->Value('user_no');
       $username = $editor->Value('username');
+      param_to_global('mode');
       include_once('caldav-PUT-functions.php');
       controlRequestContainer( $username, $user_no, $path, false, ($publicly_readable == 'on' ? true : false));
-      import_collection( $ics, $user_no, $path, $session->user_no );
+      import_collection( $ics, $user_no, $path, $session->user_no, ($mode == 'append') );
       $c->messages[] = sprintf(translate('Calendar "%s" was loaded from file.'), $path);
     }
     else {
@@ -132,6 +137,15 @@ if ( $editor->Available() ) {
   $entryqry = new AwlQuery( 'SELECT count(*) as count from caldav_data where collection_id='.$editor->Value('collection_id')  );
   $entryqry->Exec('admin-collection-edit');
   $entries = $entryqry->Fetch();  $entries = $entries->count;
+  
+  $externalqry = new AwlQuery( 'SELECT external_url from dav_binding where bound_source_id=:id  limit 1', array(':id' => $editor->Value('collection_id') ) );
+  $externalqry->Exec('external-bind-url');
+  $external = $externalqry->Fetch();  $external_url = $external->external_url;
+  if ( $external_url ) {
+    $external_bind = "\n<tr> <th class='right'>" . translate('External Url') . "</th>         <td class='left'>$external_url</td> </tr>";
+  } else {
+    $external_bind = "";
+  }
 }
 else {
   $c->page_title = $editor->Title(translate('Create New Collection'));
@@ -217,8 +231,8 @@ $btn_all = htmlspecialchars(translate('All'));             $btn_all_title = html
 $btn_rw  = htmlspecialchars(translate('Read/Write'));      $btn_rw_title = htmlspecialchars(translate('Set read+write privileges'));
 $btn_read = htmlspecialchars(translate('Read'));           $btn_read_title = htmlspecialchars(translate('Set read privileges'));
 $btn_fb = htmlspecialchars(translate('Free/Busy'));        $btn_fb_title = htmlspecialchars(translate('Set free/busy privileges'));
-$btn_sd = htmlspecialchars(translate('Schedule Deliver')); $btn_sd_title = htmlspecialchars(translate('Set schedule-deliver privileges'));
-$btn_ss = htmlspecialchars(translate('Schedule Send'));    $btn_ss_title = htmlspecialchars(translate('Set schedule-deliver privileges'));
+$btn_sd = htmlspecialchars(translate('Schedule Deliver')); $btn_sd_title = htmlspecialchars(translate('Privileges to allow delivery of scheduling messages'));
+$btn_ss = htmlspecialchars(translate('Schedule Send'));    $btn_ss_title = htmlspecialchars(translate('Privileges to delegate scheduling decisions'));
 
 
 $id = $editor->Value('collection_id');
@@ -315,10 +329,9 @@ label.privilege {
 </style>
 <table>
  <tr> <th class="right">$prompt_collection_id:</th>    <td class="left">$value_id</td> </tr>
- <tr> <th class="right">$prompt_dav_name:</th>         <td class="left">$value_dav_name</td> </tr>
+ <tr> <th class="right">$prompt_dav_name:</th>         <td class="left">$value_dav_name</td> </tr>$external_bind
  <tr> <th class="right">$prompt_entries:</th>          <td class="left">$entries</td> </tr>
- <tr> <th class="right">$prompt_load_file:</th>        <td class="left">##ics_file.file.60##
-  <label class="privilege" title="Should the uploaded entries be appended to the calendar"><input type="checkbox" name="mode" value="append">Append</label>
+ <tr> <th class="right">$prompt_load_file:</th>        <td class="left">##ics_file.file.60## ##mode.checkbox##
  </td> </tr> 
  <tr> <th class="right">$prompt_displayname:</th>      <td class="left">##dav_displayname.input.50##</td> </tr>
  <tr> <th class="right">$prompt_public:</th>           <td class="left">##publicly_readable.checkbox##</td> </tr>
@@ -347,7 +360,7 @@ label.privilege {
 </table>
 </form>
 <script language="javascript">
-toggle_enabled('fld_is_calendar','=fld_timezone','=fld_schedule_transp','!fld_is_addressbook','=fld_ics_file');
+toggle_enabled('fld_is_calendar','=fld_timezone','=fld_schedule_transp','!fld_is_addressbook');
 toggle_enabled('fld_is_addressbook','!fld_is_calendar');
 toggle_visible('fld_use_default_privs','!privileges_settings');
 </script>
