@@ -28,6 +28,12 @@ $privilege_xlate = array(
   'schedule-send' => translate('Scheduling: Sending')
 );
 
+$can_write_principal = ($session->AllowedTo('Admin') || ($session->principal_id == $id));
+if ( !$can_write_principal && $id > 0 ) {
+  $target_principal = new Principal('principal_id', $id);
+  $can_write_principal = $session->HavePrivilegeTo('DAV::write', $target_principal->dav_name());
+}
+
 
 $delete_collection_confirmation_required = null;
 $delete_principal_confirmation_required = null;
@@ -371,7 +377,7 @@ EOTEMPLATE;
 
 function build_privileges_html( $ed, $fname ) {
   global $privilege_xlate, $privilege_names;
-
+  
   $btn_all = htmlspecialchars(translate('All'));             $btn_all_title = htmlspecialchars(translate('Toggle all privileges'));
   $btn_rw  = htmlspecialchars(translate('Read/Write'));      $btn_rw_title = htmlspecialchars(translate('Set read+write privileges'));
   $btn_read = htmlspecialchars(translate('Read'));           $btn_read_title = htmlspecialchars(translate('Set read privileges'));
@@ -611,14 +617,17 @@ function grant_row_editor() {
 
 function edit_grant_row( $row_data ) {
   global $id, $grantrow;
-
-  if ( $row_data->to_principal > -1 ) {
+  
+  $orig_to_id = intval($row_data->to_principal);
+  if ( $orig_to_id > -1 ) {
+    $grantrow->SetRecord( $row_data );
+  }
+  else {
     $grantrow->Initialise( $row_data );
   }
-
+  
   $privs_html = build_privileges_html( $grantrow, 'grant_privileges' );
 
-  $orig_to_id = $row_data->to_principal;
   $form_id = $grantrow->Id();
   $form_url = preg_replace( '#&(edit|delete)_grant=\d+#', '', $_SERVER['REQUEST_URI'] );
 
@@ -937,9 +946,6 @@ if ( isset($_GET['subaction']) ) {
   }
 }
 
-
-$can_write_principal = ($session->AllowedTo('Admin') || $session->principal_id == $id );
-
 $editor = principal_editor();
 $page_elements[] = $editor;
 
