@@ -9,7 +9,7 @@ HOSTNAME=regression
 # We need to run the regression tests in the timezone they were written for.
 export PGTZ=Pacific/Auckland
 
-ALLSUITES="regression-suite binding carddav"
+ALLSUITES="regression-suite binding carddav scheduling timezone"
 
 . ./regression.conf
 
@@ -120,6 +120,11 @@ initialise_regression() {
     psql -q -f "${REGRESSION}/sample-data.sql" "${DBNAME}" >"${RESULTS}/${TEST}" 2>&1
     check_result "${TEST}"
   fi
+
+  TEST="Really-Upgrade-Database"
+  ../dba/update-davical-database --dbname=${DBNAME} --appuser davical_app --owner davical_dba >"${RESULTS}/${TEST}" 2>&1
+  check_result "${TEST}"
+
 }
 
 
